@@ -56,6 +56,7 @@
        #error Do not know how to link to Fortran libraries, check symbol table for your platform (nm libnest3.a | grep nestrun) & edit example_eggbox_C++/eggbox.cc
 #endif
 
+void initializeMalmquistPrior(LALInferenceRunState *runState);
 LALInferenceRunState *initialize(ProcessParamsTable *commandLine);
 void initializeMN(LALInferenceRunState *runState);
 void initStudentt(LALInferenceRunState *state);
@@ -123,7 +124,7 @@ void getLogLike(double *Cube, UNUSED int *ndim, UNUSED int *npars, double *lnew,
     newParams=calloc(1,sizeof(LALInferenceVariables));
     /* Make a copy of the parameters passed through currentParams */
     LALInferenceCopyVariables(runStateGlobal->currentParams,newParams);
-    int i = runStateGlobal->CubeToPrior(runStateGlobal, newParams, Cube, context);
+    int i = runStateGlobal->CubeToPrior(runStateGlobal, newParams, runStateGlobal->model, Cube, context);
 
     // if the parameters violate the prior then set likelihood to log(0);
     if( i == 0 )
@@ -135,7 +136,7 @@ void getLogLike(double *Cube, UNUSED int *ndim, UNUSED int *npars, double *lnew,
     }
 
     // calculate the loglike
-    *lnew=runStateGlobal->likelihood(newParams, runStateGlobal->data, runStateGlobal->templt);
+    *lnew=runStateGlobal->likelihood(newParams, runStateGlobal->data, runStateGlobal->model);
     *lnew -= (*(REAL8 *)LALInferenceGetVariable(runStateGlobal->algorithmParams, "logZnoise"));
     LALInferenceClearVariables(newParams);
     free(newParams);
@@ -168,12 +169,12 @@ void dumper(UNUSED int *nSamples, UNUSED int *nlive, UNUSED int *nPar, UNUSED do
     }
 
     /* Prints stats file with template and likelihood evaluation counts */
-    sprintf(outfile,"%srunstats.txt",root2);
+    /*sprintf(outfile,"%srunstats.txt",root2);
     fileout=fopen(outfile,"w");
     fprintf(fileout,"IFO templates likelihoods\n");
     for(LALInferenceIFOData *p=runStateGlobal->data;p;p=p->next)
         fprintf(fileout,"%s: %u %u\n",p->name,p->templa_counter,p->likeli_counter);
-    fclose(fileout);
+    fclose(fileout);*/
 }
 
 void getphysparams(double *Cube, UNUSED int *ndim, UNUSED int *nPar, void *context)
@@ -182,7 +183,7 @@ void getphysparams(double *Cube, UNUSED int *ndim, UNUSED int *nPar, void *conte
     LALInferenceVariables *newParams=NULL;
     newParams=calloc(1,sizeof(LALInferenceVariables));
     LALInferenceCopyVariables(runStateGlobal->currentParams,newParams);
-    runStateGlobal->CubeToPrior(runStateGlobal, newParams, Cube, context);
+    runStateGlobal->CubeToPrior(runStateGlobal, newParams, runStateGlobal->model, Cube, context);
     free(newParams);
 
     // Adjust time if necessary
@@ -201,7 +202,7 @@ void getallparams(double *Cube, UNUSED int *ndim, UNUSED int *nPar, void *contex
     LALInferenceVariables *newParams=NULL;
     newParams=calloc(1,sizeof(LALInferenceVariables));
     LALInferenceCopyVariables(runStateGlobal->currentParams,newParams);
-    runStateGlobal->CubeToPrior(runStateGlobal, newParams, Cube, context);
+    runStateGlobal->CubeToPrior(runStateGlobal, newParams, runStateGlobal->model, Cube, context);
     free(newParams);
 }
 
@@ -302,10 +303,10 @@ void LALInferenceMultiNestAlgorithm(LALInferenceRunState *runState)
 
     if( ND==0 )
     {
-        double like = runState->likelihood(runState->currentParams,runState->data,runState->templt);
+        double like = runState->likelihood(runState->currentParams,runState->data,runState->model);
         like -= (*(REAL8 *)LALInferenceGetVariable(runState->algorithmParams, "logZnoise"));
         fprintf(stdout,"LOG-LIKELIHOOD VALUE RETURNED = %g\n",like);
-        double prior = runState->prior(runState,runState->currentParams);
+        double prior = runState->prior(runState,runState->currentParams,runState->model);
         fprintf(stdout,"LOG-PRIOR VALUE RETURNED = %g\n",prior);
         fprintf(stdout,"LOG-POSTERIOR VALUE RETURNED = %g\n",like+prior);
         return;
@@ -421,7 +422,7 @@ void LALInferenceMultiNestAlgorithm(LALInferenceRunState *runState)
     double linj,pinj,lz;
         char finjname[150];
         sprintf(finjname,"%sinjlike.txt",root);
-    linj=runState->likelihood(runState->currentParams, runState->data, runState->templt);
+    linj=runState->likelihood(runState->currentParams, runState->data, runState->model);
         lz = (*(REAL8 *)LALInferenceGetVariable(runState->algorithmParams, "logZnoise"));
     linj -= lz;
     pinj = runState->prior(runState,runState->currentParams);
@@ -450,7 +451,6 @@ Initialisation arguments:\n\
 (--verbose [N])\tOutput more info. N=1: errors, N=2 (default): warnings, N=3: info \n\
 (--randomseed seed           Random seed)\n\n";
     LALInferenceRunState *irs=NULL;
-    LALInferenceIFOData *ifoPtr, *ifoListStart;
     ProcessParamsTable *ppt=NULL;
 
     irs = XLALCalloc(1, sizeof(LALInferenceRunState));
@@ -516,34 +516,6 @@ Initialisation arguments:\n\
         LALInferenceInjectInspiralSignal(irs->data,commandLine);
         fprintf(stdout, " LALInferenceInjectInspiralSignal(): finished.\n");
 
-        ifoPtr = irs->data;
-        ifoListStart = irs->data;
-        while (ifoPtr != NULL) {
-            /*If two IFOs have the same sampling rate, they should have the same timeModelh*,
-             freqModelh*, and modelParams variables to avoid excess computation
-             in model waveform generation in the future*/
-            LALInferenceIFOData * ifoPtrCompare=ifoListStart;
-            int foundIFOwithSameSampleRate=0;
-            while(ifoPtrCompare != NULL && ifoPtrCompare!=ifoPtr) {
-                if(ifoPtrCompare->timeData->deltaT == ifoPtr->timeData->deltaT){
-                    ifoPtr->timeModelhPlus=ifoPtrCompare->timeModelhPlus;
-                    ifoPtr->freqModelhPlus=ifoPtrCompare->freqModelhPlus;
-                    ifoPtr->timeModelhCross=ifoPtrCompare->timeModelhCross;
-                    ifoPtr->freqModelhCross=ifoPtrCompare->freqModelhCross;
-                    ifoPtr->modelParams=ifoPtrCompare->modelParams;
-                    foundIFOwithSameSampleRate=1;
-                    break;
-                }
-            }
-            if(!foundIFOwithSameSampleRate){
-                ifoPtr->timeModelhPlus  = XLALCreateREAL8TimeSeries("timeModelhPlus",&(ifoPtr->timeData->epoch),0.0,ifoPtr->timeData->deltaT,&lalDimensionlessUnit,ifoPtr->timeData->data->length);
-                ifoPtr->timeModelhCross = XLALCreateREAL8TimeSeries("timeModelhCross",&(ifoPtr->timeData->epoch),0.0,    ifoPtr->timeData->deltaT,&lalDimensionlessUnit,ifoPtr->timeData->data->length);
-                ifoPtr->freqModelhPlus = XLALCreateCOMPLEX16FrequencySeries("freqModelhPlus",&(ifoPtr->freqData->epoch),0.0,ifoPtr->freqData->deltaF,&lalDimensionlessUnit,ifoPtr->freqData->data->length);
-                ifoPtr->freqModelhCross = XLALCreateCOMPLEX16FrequencySeries("freqModelhCross",&(ifoPtr->freqData->epoch), 0.0, ifoPtr->freqData->deltaF, &lalDimensionlessUnit,ifoPtr->freqData->data->length);
-                ifoPtr->modelParams = XLALCalloc(1, sizeof(LALInferenceVariables));
-            }
-            ifoPtr = ifoPtr->next;
-        }
         irs->currentLikelihood=LALInferenceNullLogLikelihood(irs->data);
         printf("Null Log Likelihood: %g\n", irs->currentLikelihood);
     }
@@ -582,6 +554,35 @@ Initialisation arguments:\n\
     return(irs);
 }
 
+void initializeMalmquistPrior(LALInferenceRunState *runState)
+{
+  REAL8 malmquist_loudest = 0.0;
+  REAL8 malmquist_second_loudest = 5.0;
+  REAL8 malmquist_network = 0.0;
+  ProcessParamsTable *commandLine=runState->commandLine;
+  ProcessParamsTable *ppt=NULL;
+
+  ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-loudest-snr");
+  if(ppt)
+    malmquist_loudest = atof(ppt->value);
+  ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-second-loudest-snr");
+  if(ppt)
+    malmquist_second_loudest = atof(ppt->value);
+  ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-network-snr");
+  if(ppt)
+    malmquist_network = atof(ppt->value);
+  LALInferenceAddVariable(runState->priorArgs, "malmquist_loudest_snr", &malmquist_loudest, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+  LALInferenceAddVariable(runState->priorArgs, "malmquist_second_loudest_snr", &malmquist_second_loudest, LALINFERENCE_REAL8_t,LALINFERENCE_PARAM_FIXED);
+  LALInferenceAddVariable(runState->priorArgs, "malmquist_network_snr", &malmquist_network, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+  UINT4 malmquist=1;
+  LALInferenceAddVariable(runState->priorArgs, "malmquist", &malmquist, LALINFERENCE_UINT4_t, LALINFERENCE_PARAM_FIXED);
+  runState->prior=&LALInferenceInspiralPrior;
+  fprintf(stdout,"\nUsing Malmquist Prior with limits:\n");
+  fprintf(stdout,"Loudest SNR >= %lf\n",malmquist_loudest);
+  fprintf(stdout,"Second Loudest SNR >= %lf\n",malmquist_second_loudest);
+  fprintf(stdout,"Network SNR >= %lf\n",malmquist_network);
+}
+
 /***** Initialise MultiNest structures *****/
 /************************************************/
 void initializeMN(LALInferenceRunState *runState)
@@ -648,7 +649,6 @@ void initializeMN(LALInferenceRunState *runState)
     /* Set up the appropriate functions for MultiNest */
     runState->algorithm=&LALInferenceMultiNestAlgorithm;
 
-
     /* Set up the prior function */
     if(LALInferenceGetProcParamVal(commandLine,"--skyLocPrior")){
         runState->prior=&LALInferenceInspiralSkyLocPrior;
@@ -659,6 +659,10 @@ void initializeMN(LALInferenceRunState *runState)
     } else if (LALInferenceGetProcParamVal(commandLine, "--AnalyticPrior")) {
         runState->prior = &LALInferenceAnalyticNullPrior;
         runState->CubeToPrior = &LALInferenceAnalyticCubeToPrior;
+    } else if (LALInferenceGetProcParamVal(commandLine, "--MalmquistPrior")){
+        runState->prior = &LALInferenceInspiralPrior;
+        runState->CubeToPrior = &LALInferenceInspiralCubeToPrior;
+        initializeMalmquistPrior(runState);
     } else {
         runState->prior = &LALInferenceInspiralPriorNormalised;
         runState->CubeToPrior = &LALInferenceInspiralPriorNormalisedCubeToPrior;
@@ -757,8 +761,8 @@ Student T Likelihood Arguments:\n\
     state->likelihood = &LALInferenceFreqDomainStudentTLogLikelihood;
 
     /* Set the noise model evidence to the student t model value */
-    LALInferenceTemplateNullFreqdomain(state->data);
-    REAL8 noiseZ=LALInferenceFreqDomainStudentTLogLikelihood(state->currentParams,state->data,&LALInferenceTemplateNullFreqdomain);
+    LALInferenceTemplateNullFreqdomain(state->model);
+    REAL8 noiseZ=LALInferenceFreqDomainStudentTLogLikelihood(state->currentParams,state->data,state->model);
     LALInferenceAddVariable(state->algorithmParams,"logZnoise",&noiseZ,LALINFERENCE_REAL8_t,LALINFERENCE_PARAM_FIXED);
     fprintf(stdout,"Student-t Noise evidence %lf\n",noiseZ);
 
@@ -789,22 +793,24 @@ Arguments for each section follow:\n\n";
     /* And allocating memory */
     state = initialize(procParams);
 
-    /* Set template function */
-    LALInferenceInitCBCTemplate(state);
-
     /* Set up structures for MultiNest */
     initializeMN(state);
 
     /* Set up currentParams with variables to be used */
     /* Review task needs special priors */
     if(LALInferenceGetProcParamVal(procParams,"--correlatedGaussianLikelihood"))
-        LALInferenceInitVariablesReviewEvidence(state);
+        state->model = LALInferenceInitModelReviewEvidence(state);
     else if(LALInferenceGetProcParamVal(procParams,"--bimodalGaussianLikelihood"))
-        LALInferenceInitVariablesReviewEvidence_bimod(state);
+        state->model = LALInferenceInitModelReviewEvidence_bimod(state);
     else if(LALInferenceGetProcParamVal(procParams,"--rosenbrockLikelihood"))
-        LALInferenceInitVariablesReviewEvidence_banana(state);
+        state->model = LALInferenceInitModelReviewEvidence_banana(state);
     else
-        LALInferenceInitCBCVariables(state);
+        state->model = LALInferenceInitCBCModel(state);
+
+    state->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
+    memset(state->currentParams, 0, sizeof(LALInferenceVariables));
+    LALInferenceCopyVariables(state->model->params, state->currentParams);
+    state->templt = state->model->templt;
 
     /* Choose the likelihood */
     LALInferenceInitLikelihood(state);
