@@ -2,7 +2,7 @@
  *  LALInferenceMCMC.c:  Bayesian Followup function testing site
  *
  *  Copyright (C) 2011 Ilya Mandel, Vivien Raymond, Christian Roever,
- *  Marc van der Sluys, John Veitch and Will M. Farr
+ *  Marc van der Sluys, John Veitch, Will M. Farr, and Ben Farr
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -94,21 +94,41 @@ void LALInferenceInitMCMCState(LALInferenceRunState *state)
   /* Initialize variable that will store the name of the last proposal function used */
   const char *initPropName = "INITNAME";
   LALInferenceAddVariable(state->proposalArgs, LALInferenceCurrentProposalName, &initPropName, LALINFERENCE_string_t, LALINFERENCE_PARAM_LINEAR);
-  
+
+  /* If using a malmquist prior, force a strict prior window on distance for starting point, otherwise
+   * the approximate prior draws are very unlikely to be within the malmquist prior */
+  REAL8 dist_low, dist_high;
+  REAL8 restricted_dist_low = 10.0;
+  REAL8 restricted_dist_high = 100.0;
+  INT4 changed_dist = 0;
+  if (LALInferenceCheckVariable(state->priorArgs, "malmquist") && LALInferenceCheckVariableNonFixed(currentParams, "distance")) {
+      changed_dist = 1;
+      LALInferenceGetMinMaxPrior(state->priorArgs, "distance", &dist_low, &dist_high);
+      LALInferenceRemoveMinMaxPrior(state->priorArgs, "distance");
+      LALInferenceAddMinMaxPrior(state->priorArgs, "distance", &restricted_dist_low, &restricted_dist_high, LALINFERENCE_REAL8_t);
+  }
+
   /* If the currentParams are not in the prior, overwrite and pick paramaters from the priors. OVERWRITE EVEN USER CHOICES.
    *     (necessary for complicated prior shapes where LALInferenceCyclicReflectiveBound() is not enough */
-  while(state->prior(state, currentParams)<=-DBL_MAX){
+  LALInferenceVariables *temp=XLALCalloc(1,sizeof(LALInferenceVariables));
+  while(state->prior(state, currentParams, state->model)<=-DBL_MAX){
     fprintf(stderr, "Warning initial parameter randlomy drawn from prior. (in %s, line %d)\n",__FILE__, __LINE__);
-    LALInferenceVariables *temp; //
-    temp=XLALCalloc(1,sizeof(LALInferenceVariables));
-    memset(temp,0,sizeof(LALInferenceVariables));
-    LALInferenceDrawApproxPrior(state, temp);
+    LALInferenceDrawApproxPrior(state, currentParams, temp);
     LALInferenceCopyVariables(temp, currentParams);
   }
+  LALInferenceClearVariables(temp);
+  XLALFree(temp);
+
   /* Make sure that our initial value is within the
    *     prior-supported volume. */
   LALInferenceCyclicReflectiveBound(currentParams, priorArgs);
   
+  /* Replace distance prior if changed for initial sample draw */
+  if (changed_dist) {
+      LALInferenceRemoveMinMaxPrior(state->priorArgs, "distance");
+      LALInferenceAddMinMaxPrior(state->priorArgs, "distance", &dist_low, &dist_high, LALINFERENCE_REAL8_t);
+  }
+
   /* Init covariance matrix, if specified.  The given file
    *     should contain the desired covariance matrix for the jump
    *     proposal, in row-major (i.e. C) order. */
@@ -233,7 +253,20 @@ LALInferenceRunState *initialize(ProcessParamsTable *commandLine)
 /* and initializes other variables accordingly.                     */
 {
   LALInferenceRunState *irs=NULL;
-  LALInferenceIFOData *ifoPtr, *ifoListStart;
+  LALInferenceIFOData *ifoPtr;
+  UINT4 nifo = 0;
+  unsigned int n_basis, n_samples, time_steps;
+  n_basis = 965;//TODO: have it read from file or from command line.
+  
+  ProcessParamsTable *ppt=NULL;
+  FILE *tempfp;
+  if(LALInferenceGetProcParamVal(commandLine,"--roqtime_steps")){
+    ppt=LALInferenceGetProcParamVal(commandLine,"--roqtime_steps");
+    tempfp = fopen (ppt->value,"r");
+    fscanf (tempfp, "%u", &time_steps);
+    fscanf (tempfp, "%u", &n_basis);
+    fscanf (tempfp, "%u", &n_samples);
+  }  
 
   MPI_Comm_rank(MPI_COMM_WORLD, &MPIrank);
 
@@ -247,6 +280,7 @@ LALInferenceRunState *initialize(ProcessParamsTable *commandLine)
   /*     fLow, fHigh, detector, timeToFreqFFTPlan, freqToTimeFFTPlan,     */
   /*     window, oneSidedNoisePowerSpectrum, timeDate, freqData         ) */
   fprintf(stdout, " ==== LALInferenceReadData(): finished. ====\n");
+
   if (irs->data != NULL) {
     fprintf(stdout, " ==== initialize(): successfully read data. ====\n");
 
@@ -255,61 +289,20 @@ LALInferenceRunState *initialize(ProcessParamsTable *commandLine)
     fprintf(stdout, " ==== LALInferenceInjectInspiralSignal(): finished. ====\n");
 
     ifoPtr = irs->data;
-    ifoListStart = irs->data;
-    while (ifoPtr != NULL) {
-      /*If two IFOs have the same sampling rate, they should have the same timeModelh*,
-        freqModelh*, and modelParams variables to avoid excess computation
-        in model waveform generation in the future*/
-      LALInferenceIFOData * ifoPtrCompare=ifoListStart;
-      int foundIFOwithSameSampleRate=0;
-      while (ifoPtrCompare != NULL && ifoPtrCompare!=ifoPtr) {
-        if(ifoPtrCompare->timeData->deltaT == ifoPtr->timeData->deltaT){
-          ifoPtr->timeModelhPlus=ifoPtrCompare->timeModelhPlus;
-          ifoPtr->freqModelhPlus=ifoPtrCompare->freqModelhPlus;
-          ifoPtr->timeModelhCross=ifoPtrCompare->timeModelhCross;
-          ifoPtr->freqModelhCross=ifoPtrCompare->freqModelhCross;
-          ifoPtr->modelParams=ifoPtrCompare->modelParams;
-          foundIFOwithSameSampleRate=1;
-          break;
-        }
-        ifoPtrCompare = ifoPtrCompare->next;
-      }
-      if(!foundIFOwithSameSampleRate){
-        ifoPtr->timeModelhPlus  = XLALCreateREAL8TimeSeries("timeModelhPlus",
-                                                            &(ifoPtr->timeData->epoch),
-                                                            0.0,
-                                                            ifoPtr->timeData->deltaT,
-                                                            &lalDimensionlessUnit,
-                                                            ifoPtr->timeData->data->length);
-        ifoPtr->timeModelhCross = XLALCreateREAL8TimeSeries("timeModelhCross",
-                                                            &(ifoPtr->timeData->epoch),
-                                                            0.0,
-                                                            ifoPtr->timeData->deltaT,
-                                                            &lalDimensionlessUnit,
-                                                            ifoPtr->timeData->data->length);
-        ifoPtr->freqModelhPlus = XLALCreateCOMPLEX16FrequencySeries("freqModelhPlus",
-                                                                    &(ifoPtr->freqData->epoch),
-                                                                    0.0,
-                                                                    ifoPtr->freqData->deltaF,
-                                                                    &lalDimensionlessUnit,
-                                                                    ifoPtr->freqData->data->length);
-        ifoPtr->freqModelhCross = XLALCreateCOMPLEX16FrequencySeries("freqModelhCross",
-                                                                     &(ifoPtr->freqData->epoch),
-                                                                     0.0,
-                                                                     ifoPtr->freqData->deltaF,
-                                                                     &lalDimensionlessUnit,
-                                                                     ifoPtr->freqData->data->length);
-        ifoPtr->modelParams = XLALCalloc(1, sizeof(LALInferenceVariables));
-      }
-      ifoPtr = ifoPtr->next;
+    while (ifoPtr) {
+        nifo++;
+        ifoPtr = ifoPtr->next;
     }
+
+    irs->currentIFOLikelihoods = XLALMalloc(nifo * sizeof(REAL8));
+    irs->currentIFOSNRs = XLALMalloc(nifo * sizeof(REAL8));
+
     irs->currentLikelihood=LALInferenceNullLogLikelihood(irs->data);
     printf("Injection Null Log Likelihood: %g\n", irs->currentLikelihood);
   }
   else{
     fprintf(stdout, " initialize(): no data read.\n");
     irs = NULL;
-    return(irs);
   }
 
   return(irs);
@@ -439,9 +432,6 @@ void initializeMCMC(LALInferenceRunState *runState)
     runState->proposal=&LALInferenceDefaultProposal;
     //runState->proposal=&LALInferencetempProposal;
 
-  /* Choose the template generator for inspiral signals */
-  LALInferenceInitCBCTemplate(runState);
-
  /* runState->template=&LALInferenceTemplateLAL;
   if(LALInferenceGetProcParamVal(commandLine,"--LALSimulation")){
     runState->template=&LALInferenceTemplateXLALSimInspiralChooseWaveform;
@@ -467,6 +457,7 @@ void initializeMCMC(LALInferenceRunState *runState)
 //    runState->likelihood=&LALInferenceTimeDomainLogLikelihood;
 //  } else
 
+  UINT4 malmquist = 0;
   if(LALInferenceGetProcParamVal(commandLine,"--skyLocPrior")){
     runState->prior=&LALInferenceInspiralSkyLocPrior;
   } else if (LALInferenceGetProcParamVal(commandLine, "--correlatedGaussianLikelihood") || 
@@ -476,14 +467,38 @@ void initializeMCMC(LALInferenceRunState *runState)
     runState->prior=&LALInferenceAnalyticNullPrior;
   } else if (LALInferenceGetProcParamVal(commandLine, "--nullprior")) {
     runState->prior=&LALInferenceNullPrior;
-  } else if (LALInferenceGetProcParamVal(commandLine, "--noiseonly")) {
-    fprintf(stderr, "Using noise-only prior.\n");fflush(stdout);
-    runState->prior=&LALInferenceInspiralNoiseOnlyPrior;
+  } else if (LALInferenceGetProcParamVal(commandLine, "--malmquistprior")) {
+    printf("Using malmquist prior.\n");
+    malmquist = 1;
+    LALInferenceAddVariable(runState->priorArgs, "malmquist", &malmquist, LALINFERENCE_UINT4_t, LALINFERENCE_PARAM_FIXED);
+    runState->prior=&LALInferenceInspiralPrior;
   } else {
     runState->prior=&LALInferenceInspiralPriorNormalised;
   }
   //runState->prior=PTUniformGaussianPrior;
 
+  if (malmquist) {
+      REAL8 malmquist_loudest = 0.0;
+      REAL8 malmquist_second_loudest = 5.0;
+      REAL8 malmquist_network = 0.0;
+
+      ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-loudest-snr");
+      if(ppt)
+          malmquist_loudest = atof(ppt->value);
+
+      ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-second-loudest-snr");
+      if(ppt)
+          malmquist_second_loudest = atof(ppt->value);
+
+      ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-network-snr");
+      if(ppt)
+          malmquist_network = atof(ppt->value);
+
+      LALInferenceAddVariable(runState->priorArgs, "malmquist_loudest_snr", &malmquist_loudest, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+      LALInferenceAddVariable(runState->priorArgs, "malmquist_second_loudest_snr", &malmquist_second_loudest, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+      LALInferenceAddVariable(runState->priorArgs, "malmquist_network_snr", &malmquist_network, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+  }
+
   ppt=LALInferenceGetProcParamVal(commandLine,"--verbose");
   if(ppt) {
     verbose=1;
@@ -804,8 +819,19 @@ int main(int argc, char *argv[]){
     LALInferenceAddVariable(runState->algorithmParams,"MPIrank", &MPIrank, LALINFERENCE_UINT4_t,
                           LALINFERENCE_PARAM_FIXED);
 
-  /* Set up currentParams with variables to be used */
-  LALInferenceInitCBCVariables(runState);
+  /* Set up model struct and set currentVariables to match the initialized model params */
+  runState->model = LALInferenceInitCBCModel(runState);
+  runState->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
+  memset(runState->currentParams, 0, sizeof(LALInferenceVariables));
+  LALInferenceCopyVariables(runState->model->params, runState->currentParams);
+
+  /* Setup ROQ */
+  fprintf(stdout, " ==== LALInferenceSetupROQ(): started. ====\n");
+  LALInferenceSetupROQ(runState->data, runState->model, procParams);
+  fprintf(stdout, " ==== LALInferenceSetupROQ(): finished. ====\n");
+
+  /* Set template function in runState, since it's sometime used */
+  runState->templt = runState->model->templt;
 
   /* Choose the likelihood */
   LALInferenceInitLikelihood(runState);
