@@ -2,7 +2,7 @@
  *  LALInferenceMCMC.c:  Bayesian Followup, MCMC algorithm.
  *
  *  Copyright (C) 2009, 2012 Ilya Mandel, Vivien Raymond, Christian
- *  Roever, Marc van der Sluys, John Veitch and Will M. Farr
+ *  Roever, Marc van der Sluys, John Veitch, Will M. Farr, and Ben Farr
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -251,6 +251,9 @@ computeMaxAutoCorrLen(LALInferenceRunState *runState, INT4 startCycle, INT4 endC
     max = Niter;
   }
 
+  /* Account for any thinning of the DE buffer that has happend */
+  max *= runState->differentialPointsSkip;
+
   *maxACL = (INT4)max;
 }
 
@@ -293,7 +296,6 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
   REAL8 *ladder = NULL;			//the ladder
   REAL8 *annealDecay = NULL;
   INT4 parameter=0;
-  INT4 *intVec = NULL;
   INT4 annealStartIter = 0;
   INT4 iEffStart = 0;
   UINT4 hotChain = 0;                 // Affects proposal setup
@@ -316,7 +318,7 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
   INT4 aclCheckCounter=1;
   INT4 iEff=0;
   REAL8 ladderMin,ladderMax;
-  REAL8 timestamp,timestamp_epoch;
+  REAL8 timestamp,timestamp_epoch=0.0;
   struct timeval tv;
 
   LALInferenceMCMCRunPhase *runPhase_p = XLALCalloc(sizeof(LALInferenceMCMCRunPhase), 1);
@@ -375,7 +377,6 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
   nChain = MPIsize;		//number of parallel chain
   ladder = malloc(nChain * sizeof(REAL8));                  // Array of temperatures for parallel tempering.
   annealDecay = malloc(nChain * sizeof(REAL8));           			// Used by annealing scheme
-  intVec = malloc(nChain * sizeof(INT4));
 
   /* If not specified otherwise, set effective sample size to total number of iterations */
   if (!Neff) {
@@ -470,25 +471,41 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
       runState->likelihood==&LALInferenceFreqDomainLogLikelihood){
     nullLikelihood = LALInferenceNullLogLikelihood(runState->data);
   } else if (runState->likelihood==&LALInferenceFreqDomainStudentTLogLikelihood || 
-	     runState->likelihood==&LALInferenceMarginalisedTimeLogLikelihood) {
+	     (runState->likelihood==&LALInferenceMarginalisedTimeLogLikelihood &&
+        !LALInferenceGetProcParamVal(runState->commandLine, "--malmquistPrior")) ) {
     LALInferenceIFOData *headData = runState->data;
     REAL8 d = *(REAL8 *)LALInferenceGetVariable(runState->currentParams, "distance");
-    REAL8 bigD = 1.0 / 0.0;
+    REAL8 bigD = INFINITY;
+
+    /* Don't store to cache, since distance scaling won't work */
+    LALSimInspiralWaveformCache *cache = runState->model->waveformCache;
+    runState->model->waveformCache = NULL;
 
     LALInferenceSetVariable(runState->currentParams, "distance", &bigD);
+    nullLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->model);
 
-    nullLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->templt);
-
+    runState->model->waveformCache = cache;
     while (headData != NULL) {
-      headData->nullloglikelihood = headData->loglikelihood;
+      headData->nullloglikelihood = runState->model->loglikelihood;
       headData = headData->next;
     }
 
     LALInferenceSetVariable(runState->currentParams, "distance", &d);
   } else {
     nullLikelihood = 0.0;
+    LALInferenceIFOData *headData = runState->data;
+    while (headData != NULL) {
+      headData->nullloglikelihood = 0.0;
+      headData = headData->next;
+    }
   }
 
+  //null log likelihood logic doesn't work with noise parameters
+  if(runState->likelihood==&LALInferenceMarginalisedTimeLogLikelihood &&
+     (LALInferenceGetProcParamVal(runState->commandLine,"--psdFit") ||
+      LALInferenceGetProcParamVal(runState->commandLine,"--glitchFit") ) )
+    nullLikelihood = 0.0;
+
   LALInferenceAddVariable(runState->algorithmParams, "nChain", &nChain,  LALINFERENCE_INT4_t, LALINFERENCE_PARAM_FIXED);
   LALInferenceAddVariable(runState->algorithmParams, "nPar", &nPar,  LALINFERENCE_INT4_t, LALINFERENCE_PARAM_FIXED);
   LALInferenceAddVariable(runState->proposalArgs, "parameter",&parameter, LALINFERENCE_INT4_t, LALINFERENCE_PARAM_LINEAR);
@@ -583,13 +600,8 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
   }
 
   // initialize starting likelihood value:
-  runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->templt);
-  LALInferenceIFOData *headData = runState->data;
-  while (headData != NULL) {
-    headData->acceptedloglikelihood = headData->loglikelihood;
-    headData = headData->next;
-  }
-  runState->currentPrior = runState->prior(runState, runState->currentParams);
+  runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->model);
+  runState->currentPrior = runState->prior(runState, runState->currentParams, runState->model);
 
   REAL8 logLAtAdaptStart = runState->currentLikelihood;
   LALInferenceSetVariable(runState->proposalArgs, "logLAtAdaptStart", &(logLAtAdaptStart));
@@ -644,10 +656,10 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
     printf("%f\t", runState->currentLikelihood - nullLikelihood);
     printf("\n");
 
-    /* Print to file the contents of ->freqModelhPlus->data->length. */
+    /* Print to file the contents of model->freqhPlus. */
     ppt = LALInferenceGetProcParamVal(runState->commandLine, "--data-dump");
     if (ppt) {
-      LALInferenceDataDump(runState);
+      LALInferenceDataDump(runState->data, runState->model);
     }
   }
 
@@ -784,9 +796,12 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
       }
     } //if (*runPhase_p==SINGLE_CHAIN)
 
-    runState->evolve(runState); //evolve the chain at temperature ladder[t]
+    INT4 accepted = runState->evolve(runState); //evolve the chain at temperature ladder[t]
     acceptanceCount = *(INT4*) LALInferenceGetVariable(runState->proposalArgs, "acceptanceCount");
 
+    if (propStats)
+        LALInferenceTrackProposalAcceptance(runState, accepted);
+
     if (i==1){
       if (propStats) {
           fprintf(propstatfile, "cycle\t");
@@ -816,12 +831,25 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
       LALInferencePrintSampleNonFixed(chainoutput,runState->currentParams);
       fprintf(chainoutput,"%f\t",runState->currentLikelihood - nullLikelihood);
 
+      UINT4 ifo = 0;
       LALInferenceIFOData *headIFO = runState->data;
       while (headIFO != NULL) {
-        fprintf(chainoutput, "%f\t", headIFO->acceptedloglikelihood - headIFO->nullloglikelihood);
+        fprintf(chainoutput, "%f\t", runState->currentIFOLikelihoods[ifo] - headIFO->nullloglikelihood);
+        ifo++;
         headIFO = headIFO->next;
       }
 
+      if (LALInferenceGetProcParamVal(runState->commandLine, "--output-SNRs")) {
+          headIFO = runState->data;
+          ifo = 0;
+          while (headIFO != NULL) {
+            fprintf(chainoutput, "%f\t", runState->currentIFOSNRs[ifo]);
+            headIFO = headIFO->next;
+            ifo++;
+          }
+          fprintf(chainoutput, "%f\t", runState->model->SNR);
+      }
+
       if (benchmark) {
         gettimeofday(&tv, NULL);
         timestamp = tv.tv_sec + tv.tv_usec/1E6 - timestamp_epoch;
@@ -849,10 +877,10 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
         for(LALInferenceVariableItem *item=runState->currentParams->head;item;item=item->next){
             char tmpname[MAX_STRLEN]=""; 
             sprintf(tmpname,"%s_%s",item->name,ACCEPTSUFFIX);
-            REAL8 *accepted=(REAL8 *)LALInferenceGetVariable(runState->proposalArgs,tmpname); 
+            REAL8 *naccepted=(REAL8 *)LALInferenceGetVariable(runState->proposalArgs,tmpname); 
             sprintf(tmpname,"%s_%s",item->name,PROPOSEDSUFFIX);
-            REAL8 *proposed=(REAL8 *)LALInferenceGetVariable(runState->proposalArgs,tmpname); 
-              fprintf(statfile,"%f\t",*accepted/( *proposed==0 ? 1.0 : *proposed ));
+            REAL8 *nproposed=(REAL8 *)LALInferenceGetVariable(runState->proposalArgs,tmpname); 
+              fprintf(statfile,"%f\t",*naccepted/( *nproposed==0 ? 1.0 : *nproposed ));
         }
         fprintf(statfile,"\n");
         fflush(statfile);
@@ -865,8 +893,9 @@ void PTMCMCAlgorithm(struct tagLALInferenceRunState *runState)
       }
 
       if (propTrack) {
+        REAL8 logProposalRatio = *(REAL8*) LALInferenceGetVariable(runState->proposalArgs, "logProposalRatio");
         fprintf(proptrackfile, "%d\t", i);
-        LALInferencePrintProposalTracking(proptrackfile, runState->proposalArgs, runState->preProposalParams, runState->proposedParams);
+        LALInferencePrintProposalTracking(proptrackfile, runState->proposalArgs, runState->preProposalParams, runState->proposedParams, logProposalRatio, accepted);
       }
     }
 
@@ -939,7 +968,7 @@ void acknowledgePhase(LALInferenceRunState *runState)
     MPI_Irecv(runPhase, 1, MPI_INT, MPI_ANY_SOURCE, RUN_PHASE_COM, MPI_COMM_WORLD, &MPIrequest);
 }
 
-void PTMCMCOneStep(LALInferenceRunState *runState)
+INT4 PTMCMCOneStep(LALInferenceRunState *runState)
   // Metropolis-Hastings sampler.
 {
   int MPIrank;
@@ -965,14 +994,12 @@ void PTMCMCOneStep(LALInferenceRunState *runState)
   proposedParams.head = NULL;
   proposedParams.dimension = 0;
 
-  runState->proposal(runState, &proposedParams);
-  if (LALInferenceCheckVariable(runState->proposalArgs, "logProposalRatio"))
-    logProposalRatio = *(REAL8*) LALInferenceGetVariable(runState->proposalArgs, "logProposalRatio");
+  logProposalRatio = runState->proposal(runState, runState->currentParams, &proposedParams);
 
   // compute prior & likelihood:
-  logPriorProposed = runState->prior(runState, &proposedParams);
+  logPriorProposed = runState->prior(runState, &proposedParams, runState->model);
   if (logPriorProposed > -DBL_MAX)
-    logLikelihoodProposed = runState->likelihood(&proposedParams, runState->data, runState->templt);
+    logLikelihoodProposed = runState->likelihood(&proposedParams, runState->data, runState->model);
   else
     logLikelihoodProposed = -DBL_MAX;
 
@@ -996,12 +1023,30 @@ void PTMCMCOneStep(LALInferenceRunState *runState)
       || (log(gsl_rng_uniform(runState->GSLrandom)) < logAcceptanceProbability)) {   //accept
     LALInferenceCopyVariables(&proposedParams, runState->currentParams);
     runState->currentLikelihood = logLikelihoodProposed;
-    LALInferenceIFOData *headData = runState->data;
-    while (headData != NULL) {
-      headData->acceptedloglikelihood = headData->loglikelihood;
-      headData = headData->next;
-    }
     runState->currentPrior = logPriorProposed;
+
+    /* Calculate SNR if requested, and not already calculated by prior */
+    LALInferenceIFOData *ifoPtr = runState->data;
+    UINT4 ifo = 0;
+    if (LALInferenceGetProcParamVal(runState->commandLine, "--output-SNRs")) {
+      if (runState->model->SNR == 0.0)
+        LALInferenceNetworkSNR(runState->currentParams, runState->data, runState->model);
+      runState->currentSNR = runState->model->SNR;
+      while (ifoPtr) {
+        runState->currentIFOSNRs[ifo] = runState->model->ifo_SNRs[ifo];
+        ifo++;
+        ifoPtr = ifoPtr->next;
+      }
+    }
+
+    ifoPtr = runState->data;
+    ifo = 0;
+    while (ifoPtr) {
+      runState->currentIFOLikelihoods[ifo] = runState->model->ifo_loglikelihoods[ifo];
+      ifo++;
+      ifoPtr = ifoPtr->next;
+    }
+
     acceptanceCount++;
     accepted = 1;
     LALInferenceSetVariable(runState->proposalArgs, "acceptanceCount", &acceptanceCount);
@@ -1011,19 +1056,14 @@ void PTMCMCOneStep(LALInferenceRunState *runState)
   if (LALInferenceCheckVariable(runState->proposalArgs, "accepted"))
     LALInferenceSetVariable(runState->proposalArgs, "accepted", &accepted);
 
-  /* special (clumsy) treatment for noise parameters */
-  //???: Is there a better way to deal with accept/reject of noise parameters?
-  if(LALInferenceCheckVariable(runState->currentParams,"psdscale"))
-  {
-    gsl_matrix *nx = *((gsl_matrix **)LALInferenceGetVariable(runState->currentParams, "psdstore"));
-    gsl_matrix *ny = *((gsl_matrix **)LALInferenceGetVariable(runState->currentParams, "psdscale"));
-    if(accepted == 1) gsl_matrix_memcpy(nx,ny);
-    else              gsl_matrix_memcpy(ny,nx);
-  }
+  if (!LALInferenceCheckVariable(runState->proposalArgs, "logProposalRatio"))
+    LALInferenceAddVariable(runState->proposalArgs, "logProposalRatio", &logProposalRatio, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_LINEAR);
+  LALInferenceSetVariable(runState->proposalArgs, "logProposalRatio", &logProposalRatio);
 
-  LALInferenceTrackProposalAcceptance(runState, accepted);
   LALInferenceUpdateAdaptiveJumps(runState, accepted, targetAcceptance);
   LALInferenceClearVariables(&proposedParams);
+
+  return accepted;
 }
 
 
@@ -1216,8 +1256,8 @@ void LALInferenceLadderUpdate(LALInferenceRunState *runState, INT4 sourceChainFl
     LALInferenceCopyArrayToVariables(params, runState->currentParams);
 
     /* Update prior and likelihood */
-    runState->currentPrior = runState->prior(runState, runState->currentParams);
-    runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->templt);
+    runState->currentPrior = runState->prior(runState, runState->currentParams, runState->model);
+    runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->model);
 
     /* Restart adaptation to tune for the current location */
     LALInferenceAdaptationRestart(runState, cycle);
@@ -1284,7 +1324,7 @@ UINT4 LALInferenceMCMCMCswap(LALInferenceRunState *runState, REAL8 *ladder, INT4
     XLALDestroyREAL8Vector(adjParameters);
 
     /* Calculate likelihood at adjacent parameters and send */
-    lowLikeHighParams = runState->likelihood(adjCurrentParams, runState->data, runState->templt);
+    lowLikeHighParams = runState->likelihood(adjCurrentParams, runState->data, runState->model);
     MPI_Send(&lowLikeHighParams, 1, MPI_DOUBLE, MPIrank+1, PT_COM, MPI_COMM_WORLD);
 
     /* Determine if swap was accepted */
@@ -1310,7 +1350,7 @@ UINT4 LALInferenceMCMCMCswap(LALInferenceRunState *runState, REAL8 *ladder, INT4
 
     if (swapAccepted) {
       /* Calculate prior at new values */
-      runState->currentPrior = runState->prior(runState, runState->currentParams);
+      runState->currentPrior = runState->prior(runState, runState->currentParams, runState->model);
     }
   }
 
@@ -1346,7 +1386,7 @@ UINT4 LALInferenceMCMCMCswap(LALInferenceRunState *runState, REAL8 *ladder, INT4
       XLALDestroyREAL8Vector(adjParameters);
 
       /* Calculate likelihood at adjacent parameters */
-      highLikeLowParams = runState->likelihood(adjCurrentParams, runState->data, runState->templt);
+      highLikeLowParams = runState->likelihood(adjCurrentParams, runState->data, runState->model);
 
       /* Recieve likelihood from adjacent chain */
       MPI_Recv(&lowLikeHighParams, 1, MPI_DOUBLE, MPIrank-1, PT_COM, MPI_COMM_WORLD, &MPIstatus);
@@ -1388,7 +1428,7 @@ UINT4 LALInferenceMCMCMCswap(LALInferenceRunState *runState, REAL8 *ladder, INT4
 
       if (swapAccepted) {
         /* Calculate prior at new values */
-        runState->currentPrior = runState->prior(runState, runState->currentParams);
+        runState->currentPrior = runState->prior(runState, runState->currentParams, runState->model);
       }
     }
   }
@@ -1607,7 +1647,7 @@ void LALInferencePrintPTMCMCHeaderFile(LALInferenceRunState *runState, FILE *cha
   UINT4 benchmark=0;
   if(LALInferenceGetProcParamVal(runState->commandLine,"--benchmark")) benchmark=1;
 
-    fprintf(chainoutput, "  LALInference version:%s,%s,%s,%s,%s\n", LALAPPS_VCS_ID,LALAPPS_VCS_DATE,LALAPPS_VCS_BRANCH,LALAPPS_VCS_AUTHOR,LALAPPS_VCS_STATUS);
+    fprintf(chainoutput, "  LALInference version:%s,%s,%s,%s,%s\n", lalAppsVCSId,lalAppsVCSDate,lalAppsVCSBranch,lalAppsVCSAuthor,lalAppsVCSStatus);
     fprintf(chainoutput,"  %s\n",str);
     fprintf(chainoutput, "%10s  %10s  %6s  %20s  %6s %8s   %6s  %10s  %12s  %9s  %9s  %8s %8s\n",
         "nIter","Nburn","seed","null likelihood","Ndet","nCorr","nTemps","Tchain","Network SNR","Waveform","pN order","Npar","fRef");
@@ -1635,6 +1675,17 @@ void LALInferencePrintPTMCMCHeaderFile(LALInferenceRunState *runState, FILE *cha
       fprintf(chainoutput, "\t");
       headIFO = headIFO->next;
     }
+    if (LALInferenceGetProcParamVal(runState->commandLine, "--output-SNRs")) {
+        headIFO = runState->data;
+        while (headIFO != NULL) {
+          fprintf(chainoutput, "SNR");
+          fprintf(chainoutput, "%s",headIFO->name);
+          fprintf(chainoutput, "\t");
+          headIFO = headIFO->next;
+        }
+        fprintf(chainoutput, "SNR\t");
+    }
+
     if (benchmark)
       fprintf(chainoutput, "timestamp\t");
     fprintf(chainoutput,"\n");
@@ -1643,7 +1694,7 @@ void LALInferencePrintPTMCMCHeaderFile(LALInferenceRunState *runState, FILE *cha
     fprintf(chainoutput,"%f\t",runState->currentLikelihood - nullLikelihood);
     headIFO = runState->data;
     while (headIFO != NULL) {
-      fprintf(chainoutput, "%f\t", headIFO->acceptedloglikelihood - headIFO->nullloglikelihood);
+      fprintf(chainoutput, "%f\t", runState->currentLikelihood - headIFO->nullloglikelihood);
       headIFO = headIFO->next;
     }
     if(benchmark) {
@@ -1655,15 +1706,6 @@ void LALInferencePrintPTMCMCHeaderFile(LALInferenceRunState *runState, FILE *cha
     fprintf(chainoutput,"\n");
 }
 
-static void setIFOAcceptedLikelihoods(LALInferenceRunState *runState) {
-  LALInferenceIFOData *data = runState->data;
-  LALInferenceIFOData *ifo = NULL;
-
-  for (ifo = data; ifo != NULL; ifo = ifo->next) {
-    ifo->acceptedloglikelihood = ifo->loglikelihood;
-  }
-}
-
 void LALInferencePrintPTMCMCInjectionSample(LALInferenceRunState *runState) {
   ProcessParamsTable *ppt;
 
@@ -1788,7 +1830,7 @@ void LALInferencePrintPTMCMCInjectionSample(LALInferenceRunState *runState) {
     }
 
     LALInferenceSetVariable(runState->currentParams, "distance", &dist);
-    LALInferenceSetVariable(runState->currentParams, "inclination", &inclination);
+    LALInferenceSetVariable(runState->currentParams, "theta_JN", &inclination);
     LALInferenceSetVariable(runState->currentParams, "polarisation", &(psi));
     LALInferenceSetVariable(runState->currentParams, "declination", &dec);
     LALInferenceSetVariable(runState->currentParams, "rightascension", &ra);
@@ -1811,9 +1853,8 @@ void LALInferencePrintPTMCMCInjectionSample(LALInferenceRunState *runState) {
       LALInferenceSetVariable(runState->currentParams, "phi_spin2", &phi_spin2);
     }
 
-    runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->templt);
-    runState->currentPrior = runState->prior(runState, runState->currentParams);
-    setIFOAcceptedLikelihoods(runState);
+    runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->model);
+    runState->currentPrior = runState->prior(runState, runState->currentParams, runState->model);
     LALInferencePrintPTMCMCHeaderFile(runState, out);
     fclose(out);
 
@@ -1828,9 +1869,8 @@ void LALInferencePrintPTMCMCInjectionSample(LALInferenceRunState *runState) {
     }
 
     LALInferenceCopyVariables(saveParams, runState->currentParams);
-    runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->templt);
-    runState->currentPrior = runState->prior(runState, runState->currentParams);
-    setIFOAcceptedLikelihoods(runState);    
+    runState->currentLikelihood = runState->likelihood(runState->currentParams, runState->data, runState->model);
+    runState->currentPrior = runState->prior(runState, runState->currentParams, runState->model);
 
     XLALFree(fname);
     LALInferenceClearVariables(saveParams);
@@ -1838,85 +1878,82 @@ void LALInferencePrintPTMCMCInjectionSample(LALInferenceRunState *runState) {
   }
 }
 
-void LALInferenceDataDump(LALInferenceRunState *runState){
+void LALInferenceDataDump(LALInferenceIFOData *data, LALInferenceModel *model){
 
   const UINT4 nameLength=256;
   char filename[nameLength];
   FILE *out;
-  LALInferenceIFOData *headData = runState->data;
   UINT4 ui;
 
-  while (headData != NULL) {
+  snprintf(filename, nameLength, "freqTemplatehPlus.dat");
+  out = fopen(filename, "w");
+  for (ui = 0; ui < model->freqhPlus->data->length; ui++) {
+    REAL8 f = model->freqhPlus->deltaF * ui;
+    COMPLEX16 d = model->freqhPlus->data->data[ui];
 
-    snprintf(filename, nameLength, "%s-freqTemplatehPlus.dat", headData->name);
+    fprintf(out, "%g %g %g\n", f, creal(d), cimag(d));
+  }
+  fclose(out);
+
+  snprintf(filename, nameLength, "freqTemplatehCross.dat");
+  out = fopen(filename, "w");
+  for (ui = 0; ui < model->freqhCross->data->length; ui++) {
+    REAL8 f = model->freqhCross->deltaF * ui;
+    COMPLEX16 d = model->freqhCross->data->data[ui];
+
+    fprintf(out, "%g %g %g\n", f, creal(d), cimag(d));
+  }
+  fclose(out);
+
+  while (data != NULL) {
+    snprintf(filename, nameLength, "%s-freqTemplateStrain.dat", data->name);
     out = fopen(filename, "w");
-    for (ui = 0; ui < headData->freqModelhPlus->data->length; ui++) {
-      REAL8 f = headData->freqModelhPlus->deltaF * ui;
-      COMPLEX16 d = headData->freqModelhPlus->data->data[ui];
-
-      fprintf(out, "%g %g %g\n", f, creal(d), cimag(d));
-    }
-    fclose(out);
-
-    snprintf(filename, nameLength, "%s-freqTemplatehCross.dat", headData->name);
-    out = fopen(filename, "w");
-    for (ui = 0; ui < headData->freqModelhCross->data->length; ui++) {
-      REAL8 f = headData->freqModelhCross->deltaF * ui;
-      COMPLEX16 d = headData->freqModelhCross->data->data[ui];
-
-      fprintf(out, "%g %g %g\n", f, creal(d), cimag(d));
-    }
-    fclose(out);
-
-    snprintf(filename, nameLength, "%s-freqTemplateStrain.dat", headData->name);
-    out = fopen(filename, "w");
-    for (ui = 0; ui < headData->freqModelhCross->data->length; ui++) {
-      REAL8 f = headData->freqModelhCross->deltaF * ui;
+    for (ui = 0; ui < model->freqhCross->data->length; ui++) {
+      REAL8 f = model->freqhCross->deltaF * ui;
       COMPLEX16 d;
-      d = headData->fPlus * headData->freqModelhPlus->data->data[ui] +
-             headData->fCross * headData->freqModelhCross->data->data[ui];
+      d = data->fPlus * model->freqhPlus->data->data[ui] +
+             data->fCross * model->freqhCross->data->data[ui];
 
       fprintf(out, "%g %g %g\n", f, creal(d), cimag(d) );
     }
     fclose(out);
 
-    snprintf(filename, nameLength, "%s-timeTemplatehPlus.dat", headData->name);
+    snprintf(filename, nameLength, "%s-timeTemplateStrain.dat", data->name);
     out = fopen(filename, "w");
-    for (ui = 0; ui < headData->timeModelhPlus->data->length; ui++) {
-      REAL8 tt = XLALGPSGetREAL8(&(headData->timeModelhPlus->epoch)) +
-        ui * headData->timeModelhPlus->deltaT;
-      REAL8 d = headData->timeModelhPlus->data->data[ui];
+    for (ui = 0; ui < model->timehCross->data->length; ui++) {
+      REAL8 tt = XLALGPSGetREAL8(&(model->timehCross->epoch)) +
+        data->timeshift + ui*model->timehCross->deltaT;
+      REAL8 d = data->fPlus*model->timehPlus->data->data[ui] +
+        data->fCross*model->timehCross->data->data[ui];
 
       fprintf(out, "%.6f %g\n", tt, d);
     }
     fclose(out);
 
-    snprintf(filename, nameLength, "%s-timeTemplatehCross.dat", headData->name);
+    snprintf(filename, nameLength, "%s-timeTemplatehPlus.dat", data->name);
     out = fopen(filename, "w");
-    for (ui = 0; ui < headData->timeModelhCross->data->length; ui++) {
-      REAL8 tt = XLALGPSGetREAL8(&(headData->timeModelhCross->epoch)) +
-        ui * headData->timeModelhCross->deltaT;
-      REAL8 d = headData->timeModelhCross->data->data[ui];
+    for (ui = 0; ui < model->timehPlus->data->length; ui++) {
+      REAL8 tt = XLALGPSGetREAL8(&(model->timehPlus->epoch)) +
+        ui * model->timehPlus->deltaT;
+      REAL8 d = model->timehPlus->data->data[ui];
 
       fprintf(out, "%.6f %g\n", tt, d);
     }
     fclose(out);
 
-    snprintf(filename, nameLength, "%s-timeTemplateStrain.dat", headData->name);
+    snprintf(filename, nameLength, "%s-timeTemplatehCross.dat", data->name);
     out = fopen(filename, "w");
-    for (ui = 0; ui < headData->timeModelhCross->data->length; ui++) {
-      REAL8 tt = XLALGPSGetREAL8(&(headData->timeModelhCross->epoch)) +
-        headData->timeshift + ui*headData->timeModelhCross->deltaT;
-      REAL8 d = headData->fPlus*headData->timeModelhPlus->data->data[ui] +
-        headData->fCross*headData->timeModelhCross->data->data[ui];
+    for (ui = 0; ui < model->timehCross->data->length; ui++) {
+      REAL8 tt = XLALGPSGetREAL8(&(model->timehCross->epoch)) +
+        ui * model->timehCross->deltaT;
+      REAL8 d = model->timehCross->data->data[ui];
 
       fprintf(out, "%.6f %g\n", tt, d);
     }
     fclose(out);
 
-    headData = headData->next;
+    data = data->next;
   }
-
 }
 
 void LALInferenceMCMCResumeRead(LALInferenceRunState *runState, FILE *resumeFile) {
@@ -1926,7 +1963,7 @@ void LALInferenceMCMCResumeRead(LALInferenceRunState *runState, FILE *resumeFile
   char *last_line = NULL;
   long flen, line_length;
   int cycle;
-  float logl, logp;  
+  float loglike, logprior;  
 
   fseek(resumeFile, 0L, SEEK_END);
   flen = ftell(resumeFile);
@@ -1949,7 +1986,7 @@ void LALInferenceMCMCResumeRead(LALInferenceRunState *runState, FILE *resumeFile
   /* Go to the beginning of the last line. */
   fseek(resumeFile, -line_length, SEEK_END);
 
-  fscanf(resumeFile, "%d %f %f", &cycle, &logl, &logp);
+  fscanf(resumeFile, "%d %f %f", &cycle, &loglike, &logprior);
 
   LALInferenceReadSampleNonFixed(resumeFile, runState->currentParams);
 }
