@@ -41,9 +41,11 @@
 
 LALInferenceRunState *initialize(ProcessParamsTable *commandLine);
 void initializeNS(LALInferenceRunState *runState);
+void initializeMalmquistPrior(LALInferenceRunState *runState);
+
 void LogNSSampleAsMCMCSampleToArray(LALInferenceRunState *state, LALInferenceVariables *vars);                             
 void LogNSSampleAsMCMCSampleToFile(LALInferenceRunState *state, LALInferenceVariables *vars);                              
- 
+
 void LogNSSampleAsMCMCSampleToArray(LALInferenceRunState *state, LALInferenceVariables *vars)
 {
   NSFillMCMCVariables(vars,state->priorArgs);
@@ -68,7 +70,6 @@ Initialisation arguments:\n\
 (--randomseed seed           Random seed for Nested Sampling)\
 (--resume)\tAllow non-condor checkpointing every 4 hours. If give will check for OUTFILE_resume and continue if possible\n\n";
 	LALInferenceRunState *irs=NULL;
-	LALInferenceIFOData *ifoPtr, *ifoListStart;
 	ProcessParamsTable *ppt=NULL;
 	unsigned long int randomseed;
 	struct timeval tv;
@@ -132,34 +133,6 @@ Initialisation arguments:\n\
 		LALInferenceInjectInspiralSignal(irs->data,commandLine);
 		fprintf(stdout, " LALInferenceInjectInspiralSignal(): finished.\n");
 		
-		ifoPtr = irs->data;
-		ifoListStart = irs->data;
-		while (ifoPtr != NULL) {
-			/*If two IFOs have the same sampling rate, they should have the same timeModelh*,
-			 freqModelh*, and modelParams variables to avoid excess computation 
-			 in model waveform generation in the future*/
-			LALInferenceIFOData * ifoPtrCompare=ifoListStart;
-			int foundIFOwithSameSampleRate=0;
-			while(ifoPtrCompare != NULL && ifoPtrCompare!=ifoPtr) {
-				if(ifoPtrCompare->timeData->deltaT == ifoPtr->timeData->deltaT){
-					ifoPtr->timeModelhPlus=ifoPtrCompare->timeModelhPlus;
-					ifoPtr->freqModelhPlus=ifoPtrCompare->freqModelhPlus;
-					ifoPtr->timeModelhCross=ifoPtrCompare->timeModelhCross;				
-					ifoPtr->freqModelhCross=ifoPtrCompare->freqModelhCross;				
-					ifoPtr->modelParams=ifoPtrCompare->modelParams;	
-					foundIFOwithSameSampleRate=1;	
-					break;
-				}
-			}
-			if(!foundIFOwithSameSampleRate){
-				ifoPtr->timeModelhPlus  = XLALCreateREAL8TimeSeries("timeModelhPlus",&(ifoPtr->timeData->epoch),0.0,ifoPtr->timeData->deltaT,&lalDimensionlessUnit,ifoPtr->timeData->data->length);
-				ifoPtr->timeModelhCross = XLALCreateREAL8TimeSeries("timeModelhCross",&(ifoPtr->timeData->epoch),0.0,	ifoPtr->timeData->deltaT,&lalDimensionlessUnit,ifoPtr->timeData->data->length);
-				ifoPtr->freqModelhPlus = XLALCreateCOMPLEX16FrequencySeries("freqModelhPlus",&(ifoPtr->freqData->epoch),0.0,ifoPtr->freqData->deltaF,&lalDimensionlessUnit,ifoPtr->freqData->data->length);
-				ifoPtr->freqModelhCross = XLALCreateCOMPLEX16FrequencySeries("freqModelhCross",&(ifoPtr->freqData->epoch), 0.0, ifoPtr->freqData->deltaF, &lalDimensionlessUnit,ifoPtr->freqData->data->length);
-				ifoPtr->modelParams = XLALCalloc(1, sizeof(LALInferenceVariables));
-			}
-			ifoPtr = ifoPtr->next;
-		}
 		irs->currentLikelihood=LALInferenceNullLogLikelihood(irs->data);
 		printf("Null Log Likelihood: %g\n", irs->currentLikelihood);
 	}
@@ -193,6 +166,37 @@ Initialisation arguments:\n\
 	return(irs);
 }
 
+void initializeMalmquistPrior(LALInferenceRunState *runState)
+{
+  
+  REAL8 malmquist_loudest = 0.0;
+  REAL8 malmquist_second_loudest = 5.0;
+  REAL8 malmquist_network = 0.0;
+  ProcessParamsTable *commandLine=runState->commandLine;
+  ProcessParamsTable *ppt=NULL;
+  
+  ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-loudest-snr");
+  if(ppt)
+    malmquist_loudest = atof(ppt->value);
+  ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-second-loudest-snr");
+  if(ppt)
+    malmquist_second_loudest = atof(ppt->value);
+  ppt=LALInferenceGetProcParamVal(commandLine,"--malmquist-network-snr");
+  if(ppt)
+    malmquist_network = atof(ppt->value);
+  LALInferenceAddVariable(runState->priorArgs, "malmquist_loudest_snr", &malmquist_loudest, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+  LALInferenceAddVariable(runState->priorArgs, "malmquist_second_loudest_snr", &malmquist_second_loudest, LALINFERENCE_REAL8_t,LALINFERENCE_PARAM_FIXED);
+  LALInferenceAddVariable(runState->priorArgs, "malmquist_network_snr", &malmquist_network, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED);
+  UINT4 malmquist=1;
+  LALInferenceAddVariable(runState->priorArgs, "malmquist", &malmquist, LALINFERENCE_UINT4_t, LALINFERENCE_PARAM_FIXED);
+  runState->prior=&LALInferenceInspiralPrior;
+  fprintf(stdout,"\nUsing Malmquist Prior with limits:\n");
+  fprintf(stdout,"Loudest SNR >= %lf\n",malmquist_loudest);
+  fprintf(stdout,"Second Loudest SNR >= %lf\n",malmquist_second_loudest);
+  fprintf(stdout,"Network SNR >= %lf\n",malmquist_network);
+  
+}
+
 
 /***** Initialise Nested Sampling structures ****/
 /* Fill in samples from the prior distribution */
@@ -211,7 +215,7 @@ Nested sampling arguments:\n\
 (--Nruns R)\tNumber of parallel samples from logt to use(1)\n\
 (--tolerance dZ)\tTolerance of nested sampling algorithm (0.1)\n\
 (--randomseed seed)\tRandom seed of sampling distribution\n\
-(--prior_distr )\t Set the prior to use (for the moment the only possible choice is SkyLoc which will use the sky localization project prior. All other values or skipping this option select LALInferenceInspiralPriorNormalised)\n\n\
+(--prior )\t Set the prior to use (InspiralNormalised,SkyLoc,malmquist) default: InspiralNormalised\n\n\
 (--sampleprior N)\t For Testing: Draw N samples from the prior, will not perform the nested sampling integral\n\
   ---------------------------------------------------------------------------------------------------\n\
   --- Noise Model -----------------------------------------------------------------------------------\n\
@@ -257,14 +261,17 @@ Nested sampling arguments:\n\
 	/* Default likelihood is the frequency domain one */
 	runState->likelihood=&LALInferenceUndecomposedFreqDomainLogLikelihood;
 
-        /* Check whether to use the SkyLocalization prior. Otherwise uses the default LALInferenceInspiralPriorNormalised. That should probably be replaced with a swhich over the possible priors. */
-        ppt=LALInferenceGetProcParamVal(commandLine,"--prior_distr");
-        if(ppt){
-            if (!strcmp(ppt->value,"SkyLoc")) runState->prior = &LALInferenceInspiralSkyLocPrior;
-        }
-        else{
-            runState->prior = &LALInferenceInspiralPriorNormalised;
-        }
+    /* Check whether to use the SkyLocalization prior. Otherwise uses the default LALInferenceInspiralPriorNormalised. That should probably be replaced with a swhich over the possible priors. */
+    ppt=LALInferenceGetProcParamVal(commandLine,"--prior");
+    if(ppt){
+      if(!strcmp(ppt->value,"SkyLoc")) runState->prior = &LALInferenceInspiralSkyLocPrior;
+      if(!strcmp(ppt->value,"malmquist")) initializeMalmquistPrior(runState);
+    }
+    else{
+      runState->prior = &LALInferenceInspiralPriorNormalised;
+    }
+    /* For Compatibility with MCMC command line */
+    if(LALInferenceGetProcParamVal(commandLine,"--malmquist-prior")) initializeMalmquistPrior(runState);
 	
 	/* Set up the prior for analytic tests if needed */
 	if(LALInferenceGetProcParamVal(commandLine,"--correlatedGaussianLikelihood")){
@@ -378,22 +385,23 @@ Arguments for each section follow:\n\n";
 	/* Set up structures for nested sampling */
 	initializeNS(state);
 	
-	/* Set template function */
-	LALInferenceInitCBCTemplate(state);
-
 	/* Set up currentParams with variables to be used */
 	/* Review task needs special priors */
-	LALInferenceInitVariablesFunction initVarsFunc=NULL;
+	LALInferenceInitModelFunction initModelFunc=NULL;
 	if(LALInferenceGetProcParamVal(procParams,"--correlatedGaussianLikelihood"))
-		initVarsFunc=&LALInferenceInitVariablesReviewEvidence;
+		initModelFunc=&LALInferenceInitModelReviewEvidence;
         else if(LALInferenceGetProcParamVal(procParams,"--bimodalGaussianLikelihood"))
-                initVarsFunc=&LALInferenceInitVariablesReviewEvidence_bimod;
+                initModelFunc=&LALInferenceInitModelReviewEvidence_bimod;
         else if(LALInferenceGetProcParamVal(procParams,"--rosenbrockLikelihood"))
-                initVarsFunc=&LALInferenceInitVariablesReviewEvidence_banana;
+                initModelFunc=&LALInferenceInitModelReviewEvidence_banana;
 	else
-		initVarsFunc=&LALInferenceInitCBCVariables;
-	state->initVariables=initVarsFunc;
-	initVarsFunc(state);
+		initModelFunc=&LALInferenceInitCBCModel;
+	state->initModel=initModelFunc;
+	state->model = initModelFunc(state);
+    state->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
+    memset(state->currentParams, 0, sizeof(LALInferenceVariables));
+    LALInferenceCopyVariables(state->model->params, state->currentParams);
+    state->templt = state->model->templt;
 
         /* Choose the likelihood */
         LALInferenceInitLikelihood(state);
@@ -408,7 +416,7 @@ Arguments for each section follow:\n\n";
 	/* Call setupLivePointsArray() to populate live points structures */
 	LALInferenceSetupLivePointsArray(state);
 
-	LALInferenceSetupDefaultNSProposal(state,state->currentParams);
+	LALInferenceSetupDefaultNSProposal(state,state->currentParams,state->currentParams);
 	
 	/* write injection with noise evidence information from algorithm */
 	LALInferencePrintInjectionSample(state);
