@@ -17,61 +17,63 @@
 *  MA  02111-1307  USA
 */
 
-#include <config.h>
-
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <lalapps.h>
 #include <lal/LALMalloc.h>
 #include <lal/LALStatusMacros.h>
-#include <lal/LALVCSInfo.h>
-#include <LALAppsVCSInfo.h>
+#include <lalapps.h>
+
+#include <config.h>
+#include <LALAppsVCSInfoHeader.h>
+
+#include <lal/LALConfig.h>
+#include <lal/LALVCSInfoHeader.h>
 
 #ifdef HAVE_LIBLALFRAME
 #include <lal/LALFrameConfig.h>
-#include <lal/LALFrameVCSInfo.h>
+#include <lal/LALFrameVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALMETAIO
 #include <lal/LALMetaIOConfig.h>
-#include <lal/LALMetaIOVCSInfo.h>
+#include <lal/LALMetaIOVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALXML
 #include <lal/LALXMLConfig.h>
-#include <lal/LALXMLVCSInfo.h>
+#include <lal/LALXMLVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALSIMULATION
 #include <lal/LALSimulationConfig.h>
-#include <lal/LALSimulationVCSInfo.h>
+#include <lal/LALSimulationVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALBURST
 #include <lal/LALBurstConfig.h>
-#include <lal/LALBurstVCSInfo.h>
+#include <lal/LALBurstVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALINSPIRAL
 #include <lal/LALInspiralConfig.h>
-#include <lal/LALInspiralVCSInfo.h>
+#include <lal/LALInspiralVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALPULSAR
 #include <lal/LALPulsarConfig.h>
-#include <lal/LALPulsarVCSInfo.h>
+#include <lal/LALPulsarVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALINFERENCE
 #include <lal/LALInferenceConfig.h>
-#include <lal/LALInferenceVCSInfo.h>
+#include <lal/LALInferenceVCSInfoHeader.h>
 #endif
 
 #ifdef HAVE_LIBLALSTOCHASTIC
 #include <lal/LALStochasticConfig.h>
-#include <lal/LALStochasticVCSInfo.h>
+#include <lal/LALStochasticVCSInfoHeader.h>
 #endif
 
 #define FAILMSG( stat, func, file, line, id )                                  \
@@ -220,7 +222,7 @@ XLALGetVersionString( int level )
   if ((LAL_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lal version consistency */
-    if (version_compare(__func__, &lalHeaderVCSInfo, &lalVCSInfo))
+    if (version_compare(__func__, &lalVCSInfoHeader, &lalVCSInfo))
       exit(1);
   }
 
@@ -228,7 +230,7 @@ XLALGetVersionString( int level )
   if ((LALFRAME_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalframe version consistency */
-    if (version_compare(__func__, &lalFrameHeaderVCSInfo, &lalFrameVCSInfo))
+    if (version_compare(__func__, &lalFrameVCSInfoHeader, &lalFrameVCSInfo))
       exit(1);
   }
 #endif
@@ -237,7 +239,7 @@ XLALGetVersionString( int level )
   if ((LALMETAIO_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalmetaio version consistency */
-    if (version_compare(__func__, &lalMetaIOHeaderVCSInfo, &lalMetaIOVCSInfo))
+    if (version_compare(__func__, &lalMetaIOVCSInfoHeader, &lalMetaIOVCSInfo))
       exit(1);
   }
 #endif
@@ -246,7 +248,7 @@ XLALGetVersionString( int level )
   if ((LALSIMULATION_VERSION_DEVEL != 0) || (LALSIMULATION_VERSION_DEVEL != 0))
   {
     /* check lalsimulaton version consistency */
-    if (version_compare(__func__, &lalSimulationHeaderVCSInfo, &lalSimulationVCSInfo))
+    if (version_compare(__func__, &lalSimulationVCSInfoHeader, &lalSimulationVCSInfo))
       exit(1);
   }
 #endif
@@ -255,7 +257,7 @@ XLALGetVersionString( int level )
   if ((LALXML_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalxml version consistency */
-    if (version_compare(__func__, &lalXMLHeaderVCSInfo, &lalXMLVCSInfo))
+    if (version_compare(__func__, &lalXMLVCSInfoHeader, &lalXMLVCSInfo))
       exit(1);
   }
 #endif
@@ -264,7 +266,7 @@ XLALGetVersionString( int level )
   if ((LALBURST_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalburst version consistency */
-    if (version_compare(__func__, &lalBurstHeaderVCSInfo, &lalBurstVCSInfo))
+    if (version_compare(__func__, &lalBurstVCSInfoHeader, &lalBurstVCSInfo))
       exit(1);
   }
 #endif
@@ -273,7 +275,7 @@ XLALGetVersionString( int level )
   if ((LALINSPIRAL_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalinspiral version consistency */
-    if (version_compare(__func__, &lalInspiralHeaderVCSInfo, &lalInspiralVCSInfo))
+    if (version_compare(__func__, &lalInspiralVCSInfoHeader, &lalInspiralVCSInfo))
       exit(1);
   }
 #endif
@@ -282,7 +284,7 @@ XLALGetVersionString( int level )
   if ((LALPULSAR_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalpulsar version consistency */
-    if (version_compare(__func__, &lalPulsarHeaderVCSInfo, &lalPulsarVCSInfo))
+    if (version_compare(__func__, &lalPulsarVCSInfoHeader, &lalPulsarVCSInfo))
       exit(1);
   }
 #endif
@@ -291,7 +293,7 @@ XLALGetVersionString( int level )
   if ((LALINFERENCE_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalinference version consistency */
-    if (version_compare(__func__, &lalInferenceHeaderVCSInfo, &lalInferenceVCSInfo))
+    if (version_compare(__func__, &lalInferenceVCSInfoHeader, &lalInferenceVCSInfo))
       exit(1);
   }
 #endif
@@ -300,7 +302,7 @@ XLALGetVersionString( int level )
   if ((LALSTOCHASTIC_VERSION_DEVEL != 0) || (LALAPPS_VERSION_DEVEL != 0))
   {
     /* check lalstochastic version consistency */
-    if (version_compare(__func__, &lalStochasticHeaderVCSInfo, &lalStochasticVCSInfo))
+    if (version_compare(__func__, &lalStochasticVCSInfoHeader, &lalStochasticVCSInfo))
       exit(1);
   }
 #endif
@@ -422,8 +424,8 @@ XLALGetVersionString( int level )
           lalVCSInfo.vcsBranch,
           lalVCSInfo.vcsTag,
           lalVCSInfo.vcsStatus,
-          LAL_CONFIGURE_DATE ,
-          LAL_CONFIGURE_ARGS );
+          lalConfigureDate ,
+          lalConfigureArgs );
 
 #ifdef HAVE_LIBLALFRAME
       /* get lalframe info */
@@ -442,8 +444,8 @@ XLALGetVersionString( int level )
           lalFrameVCSInfo.vcsBranch,
           lalFrameVCSInfo.vcsTag,
           lalFrameVCSInfo.vcsStatus,
-          LALFRAME_CONFIGURE_DATE ,
-          LALFRAME_CONFIGURE_ARGS );
+          lalFrameConfigureDate ,
+          lalFrameConfigureArgs );
 #endif
 
 #ifdef HAVE_LIBLALMETAIO
@@ -463,8 +465,8 @@ XLALGetVersionString( int level )
           lalMetaIOVCSInfo.vcsBranch,
           lalMetaIOVCSInfo.vcsTag,
           lalMetaIOVCSInfo.vcsStatus,
-          LALMETAIO_CONFIGURE_DATE ,
-          LALMETAIO_CONFIGURE_ARGS );
+          lalMetaIOConfigureDate ,
+          lalMetaIOConfigureArgs );
 #endif
 
 #ifdef HAVE_LIBLALXML
@@ -484,8 +486,8 @@ XLALGetVersionString( int level )
           lalXMLVCSInfo.vcsBranch,
           lalXMLVCSInfo.vcsTag,
           lalXMLVCSInfo.vcsStatus,
-          LALXML_CONFIGURE_DATE ,
-          LALXML_CONFIGURE_ARGS );
+          lalXMLConfigureDate ,
+          lalXMLConfigureArgs );
 #endif
 
 #ifdef HAVE_LIBLALSIMULATION
@@ -505,8 +507,8 @@ XLALGetVersionString( int level )
           lalSimulationVCSInfo.vcsBranch,
           lalSimulationVCSInfo.vcsTag,
           lalSimulationVCSInfo.vcsStatus,
-          LALSIMULATION_CONFIGURE_DATE ,
-          LALSIMULATION_CONFIGURE_ARGS );
+          lalSimulationConfigureDate ,
+          lalSimulationConfigureArgs );
 #endif
 
 #ifdef HAVE_LIBLALBURST
@@ -526,11 +528,11 @@ XLALGetVersionString( int level )
           lalBurstVCSInfo.vcsBranch,
           lalBurstVCSInfo.vcsTag,
           lalBurstVCSInfo.vcsStatus,
-          LALBURST_CONFIGURE_DATE ,
-          LALBURST_CONFIGURE_ARGS );
+          lalBurstConfigureDate ,
+          lalBurstConfigureArgs );
 #endif
 
-#ifdef HAVE_LIBLALINSIRAL
+#ifdef HAVE_LIBLALINSPIRAL
       /* get lalinspiral info */
       snprintf( lalinspiral_info, sizeof(lalinspiral_info),
           "%%%% LALInspiral-Version: %s\n"
@@ -547,8 +549,8 @@ XLALGetVersionString( int level )
           lalInspiralVCSInfo.vcsBranch,
           lalInspiralVCSInfo.vcsTag,
           lalInspiralVCSInfo.vcsStatus,
-          LALINSPIRAL_CONFIGURE_DATE ,
-          LALINSPIRAL_CONFIGURE_ARGS );
+          lalInspiralConfigureDate ,
+          lalInspiralConfigureArgs );
 #endif
 
 #ifdef HAVE_LIBLALPULSAR
@@ -568,8 +570,8 @@ XLALGetVersionString( int level )
           lalPulsarVCSInfo.vcsBranch,
           lalPulsarVCSInfo.vcsTag,
           lalPulsarVCSInfo.vcsStatus,
-          LALPULSAR_CONFIGURE_DATE ,
-          LALPULSAR_CONFIGURE_ARGS );
+          lalPulsarConfigureDate ,
+          lalPulsarConfigureArgs );
 #endif
 
 #ifdef HAVE_LIBLALINFERENCE
@@ -589,8 +591,8 @@ XLALGetVersionString( int level )
           lalInferenceVCSInfo.vcsBranch,
           lalInferenceVCSInfo.vcsTag,
           lalInferenceVCSInfo.vcsStatus,
-          LALINFERENCE_CONFIGURE_DATE ,
-          LALINFERENCE_CONFIGURE_ARGS );
+          lalInferenceConfigureDate ,
+          lalInferenceConfigureArgs );
 #endif
 
 #ifdef HAVE_LIBLALSTOCHASTIC
@@ -610,8 +612,8 @@ XLALGetVersionString( int level )
           lalStochasticVCSInfo.vcsBranch,
           lalStochasticVCSInfo.vcsTag,
           lalStochasticVCSInfo.vcsStatus,
-          LALSTOCHASTIC_CONFIGURE_DATE ,
-          LALSTOCHASTIC_CONFIGURE_ARGS );
+          lalStochasticConfigureDate ,
+          lalStochasticConfigureArgs );
 #endif
 
       /* add lalapps info */
@@ -630,8 +632,8 @@ XLALGetVersionString( int level )
           lalAppsVCSInfo.vcsBranch,
           lalAppsVCSInfo.vcsTag,
           lalAppsVCSInfo.vcsStatus,
-          LALAPPS_CONFIGURE_DATE ,
-          LALAPPS_CONFIGURE_ARGS );
+          lalAppsConfigureDate ,
+          lalAppsConfigureArgs );
 
       break;
   }
