@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2010 Reinhard Prix
+ * Copyright (C) 2011, 2014 David Keitel
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
  * \author R. Prix, D. Keitel
  * \file
  * \brief
- * Generate N samples of various statistics (F-stat, LV-stat,...) drawn from their
+ * Generate N samples of various statistics (F-stat, BSGL,...) drawn from their
  * respective distributions, assuming Gaussian noise, and drawing signal params from
  * their (given) priors
  *
@@ -67,7 +68,7 @@
 
 #include <lal/SynthesizeCWDraws.h>
 
-#include <../GCT/LineVeto.h>
+#include <lal/LineRobustStats.h>
 
 #include <lal/StringVector.h>
 
@@ -82,10 +83,16 @@
 #define FALSE (1==0)
 
 /*----- Macros ----- */
-#define INIT_MEM(x) memset(&(x), 0, sizeof((x)))
-
 
 /* ---------- local types ---------- */
+/** Type containing multi- and single-detector \f$ \mathcal{F} \f$-statistics and line-robust statistic */
+typedef struct tagBSGLComponents {
+  REAL4 TwoF;				/**< multi-detector \f$ \mathcal{F} \f$-statistic value */
+  REAL4 TwoFX[PULSAR_MAX_DETECTORS];	/**< fixed-size array of single-detector \f$ \mathcal{F} \f$-statistic values */
+  UINT4 numDetectors;			/**< number of detectors, numDetectors=0 should make all code ignore the TwoFX field. */
+  REAL4 log10BSGL;			/**< line-robust statistic \f$ \log_{10}B_{\mathrm{SGL}} \f$ */
+} BSGLComponents;
+
 
 /** User-variables: can be set from config-file or command-line */
 typedef struct {
@@ -113,13 +120,18 @@ typedef struct {
   INT4 dataDuration;	/**< data-span to generate */
   INT4 TAtom;		/**< Fstat atoms time baseline */
 
-  BOOLEAN computeLV;	/**< Also compute LineVeto-statistic */
-  REAL8 LVrho;		/**< prior rho_max_line for LineVeto-statistic */
+  BOOLEAN computeBSGL;	/**< also compute line-robust statistic (BSGL) */
+  REAL8 Fstar0;		/**< transition-scale parameter F*(0) for line-robust statistic */
+  LALStringVector* oLGX; /**< Line-to-gauss prior odds oLGX for line-robust statistic */
+
+  LALStringVector* sqrtSX; /**< per-detector noise PSD sqrt(SX) */
+
   INT4 numDraws;	/**< number of random 'draws' to simulate for F-stat and B-stat */
 
   CHAR *outputStats;	/**< output file to write numDraw resulting statistics into */
   CHAR *outputAtoms;	/**< output F-statistic atoms into a file with this basename */
   CHAR *outputInjParams;/**< output injection parameters into this file */
+  BOOLEAN outputMmunuX;	/**< Whether to write the per-IFO antenna pattern matrices into the parameter file */
   BOOLEAN SignalOnly;	/**< dont generate noise-draws: will result in non-random 'signal only' values of F and B */
 
   BOOLEAN useFReg;	/**< use 'regularized' Fstat (1/D)*e^F for marginalization, or 'standard' e^F */
@@ -149,6 +161,10 @@ typedef struct {
   gsl_rng *rng;			/**< gsl random-number generator */
   CHAR *logString;		/**< logstring for file-output, containing cmdline-options + code VCS version info */
 
+  REAL4 *oLGX;			/**< per-detector line prior odds */
+
+  MultiNoiseWeights *multiNoiseWeights;	/**< per-detector noise weights SX^-1/S^-1, no per-SFT variation (can be NULL for unit weights) */
+
 } ConfigVariables;
 
 /* ---------- local prototypes ---------- */
@@ -158,17 +174,14 @@ int XLALInitUserVars ( UserInput_t *uvar );
 int XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar );
 int XLALInitAmplitudePrior ( AmplitudePrior_t *AmpPrior, const UserInput_t *uvar );
 MultiLIGOTimeGPSVector * XLALCreateMultiLIGOTimeGPSVector ( UINT4 numDetectors );
-int write_LV_candidate_to_fp ( FILE *fp, const LVcomponents *LVstat, const PulsarDopplerParams *dopplerParams_in );
+int write_BSGL_candidate_to_fp ( FILE *fp, const BSGLComponents *stats, const LALStringVector *IFOs, const InjParams_t *injParams, const BOOLEAN haveBSGL );
+MultiNoiseWeights * XLALComputeConstantMultiNoiseWeightsFromNoiseFloor (const MultiNoiseFloor *multiNoiseFloor, const MultiLIGOTimeGPSVector *multiTS, const UINT4 Tsft );
 
 /* exportable API */
 
 /*---------- Global variables ----------*/
 extern int vrbflg;		/**< defined in lalapps.c */
 
-/*---------- empty initializers ---------- */
-ConfigVariables empty_ConfigVariables;
-UserInput_t empty_UserInput;
-
 /*----------------------------------------------------------------------*/
 /* Main Function starts here */
 /*----------------------------------------------------------------------*/
@@ -178,8 +191,8 @@ UserInput_t empty_UserInput;
  */
 int main(int argc,char *argv[])
 {
-  UserInput_t uvar = empty_UserInput;
-  ConfigVariables cfg = empty_ConfigVariables;		/**< various derived configuration settings */
+  UserInput_t XLAL_INIT_DECL(uvar);
+  ConfigVariables XLAL_INIT_DECL(cfg);
 
   vrbflg = 1;	/* verbose error-messages */
   LogSetLevel(lalDebugLevel);
@@ -222,36 +235,6 @@ int main(int argc,char *argv[])
     XLAL_ERROR ( XLAL_EFUNC );
   }
 
-  /* ----- prepare stats output ----- */
-  FILE *fpStats = NULL;
-  if ( uvar.outputStats )
-    {
-      if ( (fpStats = fopen (uvar.outputStats, "wb")) == NULL)
-	{
-	  LogPrintf (LOG_CRITICAL, "Error opening file '%s' for writing..\n\n", uvar.outputStats );
-	  XLAL_ERROR ( XLAL_EIO );
-	}
-      fprintf (fpStats, "%s", cfg.logString );		/* write search log comment */
-//       if ( write_LV_candidate_to_fp ( fpStats, NULL, NULL ) != XLAL_SUCCESS ) { /* write header-line comment */
-//         XLAL_ERROR ( XLAL_EFUNC );
-//       }
-    } /* if outputStats */
-
-  /* ----- prepare injection params output ----- */
-  FILE *fpInjParams = NULL;
-  if ( uvar.outputInjParams )
-    {
-      if ( (fpInjParams = fopen (uvar.outputInjParams, "wb")) == NULL)
-	{
-	  LogPrintf (LOG_CRITICAL, "Error opening file '%s' for writing..\n\n", uvar.outputInjParams );
-	  XLAL_ERROR ( XLAL_EIO );
-	}
-      fprintf (fpInjParams, "%s", cfg.logString );		/* write search log comment */
-      if ( write_InjParams_to_fp ( fpInjParams, NULL, 0 ) != XLAL_SUCCESS ) { /* write header-line comment */
-        XLAL_ERROR ( XLAL_EFUNC );
-      }
-    } /* if outputInjParams */
-
   /* compare IFO name for line injection with IFO list, find the corresponding index, or throw an error if not found */
   UINT4 numDetectors = cfg.multiDetStates->length;
   INT4 lineX = -1;
@@ -266,64 +249,94 @@ int main(int argc,char *argv[])
     }
   }
 
+  /* ----- prepare stats output ----- */
+  FILE *fpStats = NULL;
+  if ( uvar.outputStats )
+    {
+      if ( (fpStats = fopen (uvar.outputStats, "wb")) == NULL)
+	{
+	  LogPrintf (LOG_CRITICAL, "Error opening file '%s' for writing..\n\n", uvar.outputStats );
+	  XLAL_ERROR ( XLAL_EIO );
+	}
+      fprintf (fpStats, "%s", cfg.logString );		/* write search log comment */
+      if ( write_BSGL_candidate_to_fp ( fpStats, NULL, uvar.IFOs, NULL, uvar.computeBSGL ) != XLAL_SUCCESS ) { /* write header-line comment */
+        XLAL_ERROR ( XLAL_EFUNC );
+      }
+    } /* if outputStats */
+
+  /* ----- prepare injection params output ----- */
+  FILE *fpInjParams = NULL;
+  if ( uvar.outputInjParams )
+    {
+      if ( (fpInjParams = fopen (uvar.outputInjParams, "wb")) == NULL)
+	{
+	  LogPrintf (LOG_CRITICAL, "Error opening file '%s' for writing..\n\n", uvar.outputInjParams );
+	  XLAL_ERROR ( XLAL_EIO );
+	}
+      fprintf (fpInjParams, "%s", cfg.logString );		/* write search log comment */
+      if ( write_InjParams_to_fp ( fpInjParams, NULL, 0, uvar.outputMmunuX, numDetectors ) != XLAL_SUCCESS ) { /* write header-line comment */
+        XLAL_ERROR ( XLAL_EFUNC );
+      }
+    } /* if outputInjParams */
+
+  multiAMBuffer_t XLAL_INIT_DECL(multiAMBuffer);      /* prepare AM-buffer */
+
+  /* ----- prepare BSGL computation */
+  BSGLSetup *BSGLsetup = NULL;
+  if ( uvar.computeBSGL )
+    {
+      BOOLEAN useLogCorrection = TRUE;
+      REAL4 *oLGX_p = NULL;
+      REAL4 oLGX[PULSAR_MAX_DETECTORS];
+      if ( uvar.oLGX != NULL )
+        {
+          XLAL_CHECK ( uvar.oLGX->length == numDetectors, XLAL_EINVAL, "Invalid input: length(oLGX) = %d differs from number of detectors (%d)'\n", uvar.oLGX->length, numDetectors );
+          XLAL_CHECK ( XLALParseLinePriors ( &oLGX[0], uvar.oLGX ) == XLAL_SUCCESS, XLAL_EFUNC );
+          oLGX_p = &oLGX[0];
+        }
+      XLAL_CHECK ( ( BSGLsetup = XLALCreateBSGLSetup ( numDetectors, uvar.Fstar0, oLGX_p, useLogCorrection ) ) != NULL, XLAL_EFUNC );
+    } // if computeBSGL
+
   /* ----- main MC loop over numDraws trials ---------- */
   INT4 i;
   for ( i=0; i < uvar.numDraws; i ++ )
     {
-      InjParams_t injParamsDrawn = empty_InjParams_t;
+      InjParams_t XLAL_INIT_DECL(injParamsDrawn);
 
       /* ----- generate signal random draws from ranges and generate Fstat atoms */
-      multiAMBuffer_t multiAMBuffer = empty_multiAMBuffer;      /* prepare AM-buffer */
       MultiFstatAtomVector *multiAtoms;
 
-      multiAtoms = XLALSynthesizeTransientAtoms ( &injParamsDrawn, cfg.skypos, cfg.AmpPrior, cfg.transientInjectRange, cfg.multiDetStates, cfg.SignalOnly, &multiAMBuffer, cfg.rng, lineX);
+      multiAtoms = XLALSynthesizeTransientAtoms ( &injParamsDrawn, cfg.skypos, cfg.AmpPrior, cfg.transientInjectRange, cfg.multiDetStates, cfg.SignalOnly, &multiAMBuffer, cfg.rng, lineX, cfg.multiNoiseWeights );
       XLAL_CHECK ( multiAtoms != NULL, XLAL_EFUNC );
 
       /* ----- if requested, output signal injection parameters into file */
-      if ( fpInjParams && (write_InjParams_to_fp ( fpInjParams, &injParamsDrawn, uvar.dataStartGPS ) != XLAL_SUCCESS ) ) {
+      if ( fpInjParams && (write_InjParams_to_fp ( fpInjParams, &injParamsDrawn, uvar.dataStartGPS, uvar.outputMmunuX, numDetectors ) != XLAL_SUCCESS ) ) {
         XLAL_ERROR ( XLAL_EFUNC );
       } /* if fpInjParams & failure*/
 
-      /* initialise LVcomponents structure and allocate memory */
-      LVcomponents   lvstats;      /* struct containing multi-detector Fstat, single-detector Fstats, Line Veto stat */
-      if ( (lvstats.TwoFX = XLALCreateREAL4Vector ( numDetectors )) == NULL ) {
-        XLALPrintError ("%s: failed to XLALCreateREAL4Vector( %d )\n", __func__, numDetectors );
-        XLAL_ERROR ( XLAL_EFUNC );
-      }
+      /* initialise BSGLComponents structure and allocate memory */
+      BSGLComponents XLAL_INIT_DECL(synthStats); /* struct containing multi-detector Fstat, single-detector Fstats, line-robust stat */
+      synthStats.numDetectors = numDetectors;
 
-      REAL8Vector *linepriorX;
-      if ( (linepriorX = XLALCreateREAL8Vector ( numDetectors )) == NULL ) {
-        XLALPrintError ("%s: failed to XLALCreateREAL8Vector( %d )\n", __func__, numDetectors );
-        XLAL_ERROR ( XLAL_EFUNC );
-      }
-
-      /* compute F and LV statistics from atoms */
+      /* compute F- and BSGListics from atoms */
       UINT4 X;
       for ( X=0; X < numDetectors; X++ )    {
-        linepriorX->data[X] = 0.5;
-        lvstats.TwoFX->data[X] = 2.0*XLALComputeFstatFromAtoms ( multiAtoms, X );
+        synthStats.TwoFX[X] = XLALComputeFstatFromAtoms ( multiAtoms, X );
         if ( xlalErrno != 0 ) {
           XLALPrintError ("\nError in function %s, line %d : Failed call to XLALComputeFstatFromAtoms().\n\n", __func__, __LINE__);
           XLAL_ERROR ( XLAL_EFUNC );
         }
       }
 
-      lvstats.TwoF = 2.0*XLALComputeFstatFromAtoms ( multiAtoms, -1 );
+      synthStats.TwoF = XLALComputeFstatFromAtoms ( multiAtoms, -1 );
       if ( xlalErrno != 0 ) {
         XLALPrintError ("\nError in function %s, line %d : Failed call to XLALComputeFstatFromAtoms().\n\n", __func__, __LINE__);
         XLAL_ERROR ( XLAL_EFUNC );
       }
 
-      if ( uvar.computeLV ) {
-        BOOLEAN useAllTerms = TRUE;
-        lvstats.LV = XLALComputeLineVeto ( (REAL4)lvstats.TwoF, (REAL4Vector*)lvstats.TwoFX, uvar.LVrho, linepriorX, useAllTerms );
-        if ( xlalErrno != 0 ) {
-          XLALPrintError ("\nError in function %s, line %d : Failed call to XLALComputeLineVeto().\n\n", __func__, __LINE__);
-          XLAL_ERROR ( XLAL_EFUNC );
-        }
-      }
-      else {
-       lvstats.LV = 0.0;
+      if ( uvar.computeBSGL ) {
+        synthStats.log10BSGL = XLALComputeBSGL ( synthStats.TwoF, synthStats.TwoFX, BSGLsetup );
+        XLAL_CHECK ( xlalErrno == 0, XLAL_EFUNC, "XLALComputeBSGL() failed with xlalErrno = %d\n", xlalErrno );
       }
 
       /* ----- if requested, output atoms-vector into file */
@@ -356,16 +369,13 @@ int main(int argc,char *argv[])
 
 
       /* ----- if requested, output transient-cand statistics */
-      if ( fpStats && write_LV_candidate_to_fp ( fpStats, &lvstats, NULL ) != XLAL_SUCCESS ) {
+      if ( fpStats && write_BSGL_candidate_to_fp ( fpStats, &synthStats, uvar.IFOs, &injParamsDrawn, uvar.computeBSGL ) != XLAL_SUCCESS ) {
         XLALPrintError ( "%s: write_transientCandidate_to_fp() failed.\n", __func__ );
         XLAL_ERROR ( XLAL_EFUNC );
       }
 
       /* ----- free Memory */
-      XLALDestroyREAL4Vector ( lvstats.TwoFX );
-      XLALDestroyREAL8Vector ( linepriorX );
       XLALDestroyMultiFstatAtomVector ( multiAtoms );
-      XLALDestroyMultiAMCoeffs ( multiAMBuffer.multiAM );
 
     } /* for i < numDraws */
 
@@ -375,14 +385,21 @@ int main(int argc,char *argv[])
 
   /* ----- free memory ---------- */
   XLALDestroyMultiDetectorStateSeries ( cfg.multiDetStates );
+  XLALDestroyMultiNoiseWeights ( cfg.multiNoiseWeights );
   XLALDestroyExpLUT();
+  XLALDestroyMultiAMCoeffs ( multiAMBuffer.multiAM );
   /* ----- free amplitude prior pdfs ----- */
   XLALDestroyPDF1D ( cfg.AmpPrior.pdf_h0Nat );
   XLALDestroyPDF1D ( cfg.AmpPrior.pdf_cosi );
   XLALDestroyPDF1D ( cfg.AmpPrior.pdf_psi );
   XLALDestroyPDF1D ( cfg.AmpPrior.pdf_phi0 );
 
-  if ( cfg.logString ) XLALFree ( cfg.logString );
+  XLALFree ( BSGLsetup );
+  BSGLsetup = NULL;
+
+  if ( cfg.logString ) {
+    XLALFree ( cfg.logString );
+  }
   gsl_rng_free ( cfg.rng );
 
   XLALDestroyUserVars();
@@ -420,8 +437,11 @@ XLALInitUserVars ( UserInput_t *uvar )
   uvar->numDraws = 1;
   uvar->TAtom = 1800;
 
-  uvar->computeLV = 0;
-  uvar->LVrho = 0.0;
+  uvar->computeBSGL = 1;
+  uvar->Fstar0 = -LAL_REAL4_MAX; /* corresponding to OSL limit */
+  uvar->oLGX = NULL;
+
+  uvar->sqrtSX = NULL;
   uvar->useFReg = 0;
 
   uvar->fixedh0Nat = -1;
@@ -463,15 +483,19 @@ XLALInitUserVars ( UserInput_t *uvar )
   XLALregINTUserStruct ( dataDuration,	 	 0,  UVAR_OPTIONAL, "data-span to generate (in seconds)");
 
   /* misc params */
-  XLALregBOOLUserStruct ( computeLV,		 0, UVAR_OPTIONAL, "Also compute LineVeto-statistic");
-  XLALregREALUserStruct ( LVrho,		 0, UVAR_OPTIONAL, "prior rho_max_line for LineVeto-statistic");
+  XLALregBOOLUserStruct ( computeBSGL,		 0, UVAR_OPTIONAL, "Compute line-robust statistic (BSGL)");
+  XLALregREALUserStruct ( Fstar0,		 0, UVAR_OPTIONAL, "BSGL: transition-scale parameter 'Fstar0'");
+  XLALregLISTUserStruct ( oLGX,			 0, UVAR_OPTIONAL, "BSGL: prior per-detector line-vs-Gauss odds, length must be numDetectors. (Defaults to oLGX=1/Ndet)");
+
+  XLALregLISTUserStruct ( sqrtSX,		 0, UVAR_OPTIONAL, "Per-detector noise PSD sqrt(SX). Only ratios relevant to compute noise weights. Defaults to 1,1,...");
 
   XLALregINTUserStruct  ( numDraws,		'N', UVAR_OPTIONAL,"Number of random 'draws' to simulate");
   XLALregINTUserStruct  ( randSeed,		 0, UVAR_OPTIONAL, "GSL random-number generator seed value to use");
 
   XLALregSTRINGUserStruct ( outputStats,	'o', UVAR_OPTIONAL, "Output file containing 'numDraws' random draws of stats");
   XLALregSTRINGUserStruct ( outputAtoms,	 0,  UVAR_OPTIONAL, "Output F-statistic atoms into a file with this basename");
-  XLALregSTRINGUserStruct ( outputInjParams,	 0,  UVAR_OPTIONAL,  "Output injection parameters into this file");
+  XLALregSTRINGUserStruct ( outputInjParams,	 0,  UVAR_OPTIONAL, "Output injection parameters into this file");
+  XLALregBOOLUserStruct ( outputMmunuX,        	 0,  UVAR_OPTIONAL, "Write the per-IFO antenna pattern matrices into the parameter file");
 
   XLALregBOOLUserStruct ( SignalOnly,        	'S', UVAR_OPTIONAL, "Signal only: generate pure signal without noise");
   XLALregBOOLUserStruct ( useFReg,        	 0,  UVAR_OPTIONAL, "use 'regularized' Fstat (1/D)*e^F (if TRUE) for marginalization, or 'standard' e^F (if FALSE)");
@@ -484,7 +508,6 @@ XLALInitUserVars ( UserInput_t *uvar )
   /* 'hidden' stuff */
   XLALregINTUserStruct ( TAtom,		  	  0, UVAR_DEVELOPER, "Time baseline for Fstat-atoms (typically Tsft) in seconds." );
 
-
   if ( xlalErrno ) {
     XLALPrintError ("%s: something failed in initializing user variabels .. errno = %d.\n", __func__, xlalErrno );
     XLAL_ERROR ( XLAL_EFUNC );
@@ -555,21 +578,8 @@ XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar )
   }
 
   UINT4 numDetectors = uvar->IFOs->length;
-  UINT4 X;
-  MultiLALDetector *multiDet;
-  if ( (multiDet = XLALCreateMultiLALDetector ( numDetectors )) == NULL ) {
-    XLALPrintError ("%s: XLALCreateMultiLALDetector(1) failed with errno=%d\n", __func__, xlalErrno );
-    XLAL_ERROR ( XLAL_EFUNC );
-  }
-  LALDetector *site = NULL;
-  for ( X=0; X < numDetectors; X++ )    {
-    if ( (site = XLALGetSiteInfo ( uvar->IFOs->data[X] )) == NULL ) {
-      XLALPrintError ("%s: Failed to get site-info for detector '%s'\n", __func__, uvar->IFOs->data[X] );
-      XLAL_ERROR ( XLAL_EFUNC );
-    }
-    multiDet->data[X] = (*site); 	/* copy! */
-    XLALFree ( site );
-  }
+  MultiLALDetector multiDet;
+  XLAL_CHECK ( XLALParseMultiLALDetector ( &multiDet, uvar->IFOs ) == XLAL_SUCCESS, XLAL_EFUNC );
 
   /* init timestamps vector covering observation time */
   UINT4 numSteps = (UINT4) ceil ( uvar->dataDuration / uvar->TAtom );
@@ -578,7 +588,7 @@ XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar )
      XLALPrintError ("%s: XLALCreateMultiLIGOTimeGPSVector(%d) failed.\n", __func__, numDetectors );
   }
 
-  for ( X=0; X < numDetectors; X++ )    {
+  for ( UINT4 X=0; X < numDetectors; X++ )    {
     if ( (multiTS->data[X] = XLALCreateTimestampVector (numSteps)) == NULL ) {
       XLALPrintError ("%s: XLALCreateTimestampVector(%d) failed.\n", __func__, numSteps );
     }
@@ -593,16 +603,24 @@ XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar )
   }
 
   /* get detector states */
-  if ( (cfg->multiDetStates = XLALGetMultiDetectorStates ( multiTS, multiDet, edat, 0.5 * uvar->TAtom )) == NULL ) {
+  if ( (cfg->multiDetStates = XLALGetMultiDetectorStates ( multiTS, &multiDet, edat, 0.5 * uvar->TAtom )) == NULL ) {
     XLALPrintError ( "%s: XLALGetMultiDetectorStates() failed.\n", __func__ );
     XLAL_ERROR ( XLAL_EFUNC );
   }
 
+  if ( uvar->sqrtSX ) { /* translate user-input PSD sqrt(SX) to noise-weights (this actually does not care whether they were normalized or not) */
+
+    /* parse input comma-separated list */
+    MultiNoiseFloor multiNoiseFloor;
+    XLAL_CHECK ( XLALParseMultiNoiseFloor ( &multiNoiseFloor, uvar->sqrtSX, numDetectors ) == XLAL_SUCCESS, XLAL_EFUNC );
+
+    /* translate to noise weights */
+    XLAL_CHECK ( ( cfg->multiNoiseWeights = XLALComputeConstantMultiNoiseWeightsFromNoiseFloor ( &multiNoiseFloor, multiTS, uvar->TAtom ) ) != NULL, XLAL_EFUNC );
+
+  } /* if ( uvar->sqrtSX ) */
+
   /* get rid of all temporary memory allocated for this step */
-  XLALDestroyMultiLALDetector ( multiDet );
-  XLALFree(edat->ephemE);
-  XLALFree(edat->ephemS);
-  XLALFree ( edat );
+  XLALDestroyEphemerisData ( edat );
   XLALDestroyMultiTimestamps ( multiTS );
   multiTS = NULL;
 
@@ -784,59 +802,121 @@ XLALCreateMultiLIGOTimeGPSVector ( UINT4 numDetectors )
 
 
 /**
- * Write one line for given LV candidate into output file.
+ * Write one line for given BSGL candidate into output file.
  *
- * NOTE: input dopplerParams can be NULL pointer, then just writes 0 in doppler fields (useful for synthetic LV draws)
+ * NOTE: input stats and injParams can be NULL pointers, then writes header comment instead
  *
  */
 int
-write_LV_candidate_to_fp ( FILE *fp, const LVcomponents *LVstat, const PulsarDopplerParams *dopplerParams_in )
+write_BSGL_candidate_to_fp ( FILE *fp, const BSGLComponents *stats, const LALStringVector *IFOs, const InjParams_t *injParams, const BOOLEAN haveBSGL )
 {
-  /* sanity checks */
-  if ( !fp ) {
-    XLALPrintError ( "%s: invalid NULL filepointer input.\n", __func__ );
-    XLAL_ERROR ( XLAL_EINVAL );
-  }
-  if ( !LVstat || !LVstat->TwoFX || !LVstat->TwoFX->data ) {
-    XLALPrintError ("\nError in function %s, line %d : Empty LVstat pointer as input parameter!\n\n", __func__, __LINE__);
-    XLAL_ERROR ( XLAL_EFAULT);
-  }
 
-  PulsarDopplerParams dopplerParams = empty_PulsarDopplerParams;
-  INIT_MEM( dopplerParams.fkdot );
-  if ( dopplerParams_in == NULL ) { /* just write zeros */
-    dopplerParams.Alpha = 0.0;
-    dopplerParams.Delta = 0.0;
-  }
-  else {
-    dopplerParams = *dopplerParams_in;
-  }
+  XLAL_CHECK ( fp, XLAL_EINVAL, "Invalid NULL filepointer input." );
+
+  /* if requested, write header-comment line */
+  if ( !stats && !injParams ) {
+
+    char stat_header_string[256] = "";
+    char buf0[256];
+    snprintf ( stat_header_string, sizeof(stat_header_string), "2F   " );
+    for ( UINT4 X = 0; X < IFOs->length ; X ++ ) {
+      snprintf ( buf0, sizeof(buf0), "    2F_%s", IFOs->data[X] );
+      UINT4 len1 = strlen ( stat_header_string ) + strlen ( buf0 ) + 1;
+      XLAL_CHECK ( len1 <= sizeof ( stat_header_string ), XLAL_EBADLEN, "Assembled output string too long! (%d > %d)", len1, sizeof(stat_header_string));
+      strcat ( stat_header_string, buf0 );
+    }
+    if ( haveBSGL ) {
+      snprintf ( buf0, sizeof(buf0), "     log10BSGL" );
+      strcat ( stat_header_string, buf0 );
+    }
+    fprintf(fp, "%%%% freq  alpha    delta    f1dot    %s\n", stat_header_string);
+
+    return XLAL_SUCCESS;	/* we're done here */
+
+  } /* if par == NULL */
+
+  /* sanity checks */
+  XLAL_CHECK ( stats, XLAL_EFAULT, "Invalid stats pointer as input parameter!" );
+  XLAL_CHECK ( injParams, XLAL_EFAULT, "Invalid injParams pointer as input parameter!" );
 
   /* add output-field containing twoF and per-detector sumTwoFX */
   char statString[256] = "";	/* defaults to empty */
   char buf0[256];
-  snprintf ( statString, sizeof(statString), " %.6f", LVstat->TwoF );
-  UINT4 numDet = LVstat->TwoFX->length;
-  UINT4 X;
-  for ( X = 0; X < numDet ; X ++ ) {
-    snprintf ( buf0, sizeof(buf0), " %.6f", LVstat->TwoFX->data[X] );
+  snprintf ( statString, sizeof(statString), "%.6f", stats->TwoF );
+  for ( UINT4 X = 0; X < IFOs->length ; X ++ ) {
+    snprintf ( buf0, sizeof(buf0), " %.6f", stats->TwoFX[X] );
     UINT4 len1 = strlen ( statString ) + strlen ( buf0 ) + 1;
-    if ( len1 > sizeof ( statString ) ) {
-      XLALPrintError ("%s: assembled output string too long! (%d > %d)\n", __func__, len1, sizeof(statString));
-      break;	/* we can't really terminate with error in this function, but at least we avoid crashing */
-    }
+    XLAL_CHECK ( len1 <= sizeof ( statString ), XLAL_EBADLEN, "Assembled output string too long! (%d > %d)", len1, sizeof(statString));
     strcat ( statString, buf0 );
-  } /* for X < numDet */
-  snprintf ( buf0, sizeof(buf0), " %.6f", LVstat->LV );
-  strcat ( statString, buf0 );
-  fprintf (fp, "%.16g %.13g %.13g %.13g%s\n",
-		dopplerParams.fkdot[0],
-		dopplerParams.Alpha,
-		dopplerParams.Delta,
-		dopplerParams.fkdot[1],
-		statString
+  } /* for X < IFOs->length */
+  if ( haveBSGL ) {
+    snprintf ( buf0, sizeof(buf0), " %.6f", stats->log10BSGL );
+    strcat ( statString, buf0 );
+  }
+  fprintf (fp, "%.6f %.6f %.6f %.6f %s\n",
+		0.0, /* legacy field from synthesizeTransientStats: freq, not needed here */
+		injParams->skypos.longitude,
+		injParams->skypos.latitude,
+		0.0,
+		statString /* legacy field from synthesizeTransientStats: f1dot, not needed here */
 	    );
 
   return XLAL_SUCCESS;
 
-} /* write_LV_candidate_to_fp() */
+} /* write_BSGL_candidate_to_fp() */
+
+
+/**
+ *
+ */
+MultiNoiseWeights *
+XLALComputeConstantMultiNoiseWeightsFromNoiseFloor ( const MultiNoiseFloor *multiNoiseFloor,	/**< [in] noise floor values sqrt(S) for all detectors */
+                                                     const MultiLIGOTimeGPSVector *multiTS,	/**< [in] timestamps vectors for all detectors, only needed for their lengths */
+                                                     const UINT4 Tsft				/**< [in] length of SFTs in secons, needed for normalization factor Sinv_Tsft */
+                                                     )
+{
+
+  /* check input parameters */
+  XLAL_CHECK_NULL ( multiNoiseFloor != NULL, XLAL_EINVAL );
+  XLAL_CHECK_NULL ( multiTS != NULL, XLAL_EINVAL );
+  UINT4 numDet = multiNoiseFloor->length;
+  XLAL_CHECK_NULL ( numDet == multiTS->length, XLAL_EINVAL, "Inconsistent length between multiNoiseFloor (%d) and multiTimeStamps (%d) structs.\n", numDet, multiTS->length );
+
+  /* create multi noise weights for output */
+  MultiNoiseWeights *multiWeights = NULL;
+  XLAL_CHECK_NULL ( (multiWeights = XLALCalloc(1, sizeof(*multiWeights))) != NULL, XLAL_ENOMEM, "Failed call to XLALCalloc ( 1, %d )\n", sizeof(*multiWeights) );
+  XLAL_CHECK_NULL ( (multiWeights->data = XLALCalloc(numDet, sizeof(*multiWeights->data))) != NULL, XLAL_ENOMEM, "Failed call to XLALCalloc ( %d, %d )\n", numDet, sizeof(*multiWeights->data) );
+  multiWeights->length = numDet;
+
+  REAL8 sqrtSnTotal = 0;
+  UINT4 numSFTsTotal = 0;
+  for (UINT4 X = 0; X < numDet; X++) { /* first loop over detectors: compute total noise floor normalization */
+    sqrtSnTotal  += multiTS->data[X]->length / SQ ( multiNoiseFloor->sqrtSn[X] ); /* actually summing up 1/Sn, not sqrtSn yet */
+    numSFTsTotal += multiTS->data[X]->length;
+  }
+  sqrtSnTotal = sqrt ( numSFTsTotal / sqrtSnTotal ); /* SnTotal = harmonicMean{S_X} assuming per-detector stationarity */
+
+  for (UINT4 X = 0; X < numDet; X++) { /* second loop over detectors: compute the weights */
+
+    /* compute per-IFO weights */
+    REAL8 noise_weight_X = SQ(sqrtSnTotal/multiNoiseFloor->sqrtSn[X]); /* w_Xalpha = S_Xalpha^-1/S^-1 = S / S_Xalpha */
+
+    /* create k^th weights vector */
+    if( ( multiWeights->data[X] = XLALCreateREAL8Vector ( multiTS->data[X]->length ) ) == NULL ) {
+      /* free weights vectors created previously in loop */
+      XLALDestroyMultiNoiseWeights ( multiWeights );
+      XLAL_ERROR_NULL ( XLAL_EFUNC, "Failed to allocate noiseweights for IFO X = %d\n", X );
+    } /* if XLALCreateREAL8Vector() failed */
+
+    /* loop over SFT timestamps and use same weights for all */
+    for ( UINT4 alpha = 0; alpha < multiTS->data[X]->length; alpha++) {
+      multiWeights->data[X]->data[alpha] = noise_weight_X;
+    }
+
+  } /* for X < numDet */
+
+  multiWeights->Sinv_Tsft = Tsft / SQ ( sqrtSnTotal );
+
+  return multiWeights;
+
+} /* XLALComputeConstantMultiNoiseWeightsFromNoiseFloor() */
