@@ -167,10 +167,6 @@ int XLALInitAmplitudePrior ( AmplitudePrior_t *AmpPrior, const UserInput_t *uvar
 /*---------- Global variables ----------*/
 extern int vrbflg;		/**< defined in lalapps.c */
 
-/*---------- empty initializers ---------- */
-ConfigVariables empty_ConfigVariables;
-UserInput_t empty_UserInput;
-
 /*----------------------------------------------------------------------*/
 /* Main Function starts here */
 /*----------------------------------------------------------------------*/
@@ -180,8 +176,8 @@ UserInput_t empty_UserInput;
  */
 int main(int argc,char *argv[])
 {
-  UserInput_t uvar = empty_UserInput;
-  ConfigVariables cfg = empty_ConfigVariables;		/**< various derived configuration settings */
+  UserInput_t XLAL_INIT_DECL(uvar);
+  ConfigVariables XLAL_INIT_DECL(cfg);		/**< various derived configuration settings */
 
   vrbflg = 1;	/* verbose error-messages */
   LogSetLevel(lalDebugLevel);
@@ -249,35 +245,35 @@ int main(int argc,char *argv[])
 	  XLAL_ERROR ( XLAL_EIO );
 	}
       fprintf (fpInjParams, "%s", cfg.logString );		/* write search log comment */
-      if ( write_InjParams_to_fp ( fpInjParams, NULL, 0 ) != XLAL_SUCCESS ) { /* write header-line comment */
+      if ( write_InjParams_to_fp ( fpInjParams, NULL, 0, 0, 0 ) != XLAL_SUCCESS ) { /* write header-line comment - options outputMmunuX and numDetectors not supported here, so pass defaults to deactivate them */
         XLAL_ERROR ( XLAL_EFUNC );
       }
     } /* if outputInjParams */
 
   /* ----- main MC loop over numDraws trials ---------- */
-  multiAMBuffer_t multiAMBuffer = empty_multiAMBuffer;	  /* prepare AM-buffer */
+  multiAMBuffer_t XLAL_INIT_DECL(multiAMBuffer);	  /* prepare AM-buffer */
   INT4 i;
 
   for ( i=0; i < uvar.numDraws; i ++ )
     {
-      InjParams_t injParamsDrawn = empty_InjParams_t;
+      InjParams_t XLAL_INIT_DECL(injParamsDrawn);
 
       /* ----- generate signal random draws from ranges and generate Fstat atoms */
       MultiFstatAtomVector *multiAtoms;
-      multiAtoms = XLALSynthesizeTransientAtoms ( &injParamsDrawn, cfg.skypos, cfg.AmpPrior, cfg.transientInjectRange, cfg.multiDetStates, cfg.SignalOnly, &multiAMBuffer, cfg.rng, -1);
+      multiAtoms = XLALSynthesizeTransientAtoms ( &injParamsDrawn, cfg.skypos, cfg.AmpPrior, cfg.transientInjectRange, cfg.multiDetStates, cfg.SignalOnly, &multiAMBuffer, cfg.rng, -1, NULL ); // options lineX and noise_weights not supported here, so pass defaults to deactivate them
       if ( multiAtoms ==NULL ) {
         LogPrintf ( LOG_CRITICAL, "%s: XLALSynthesizeTransientAtoms() failed with xlalErrno = %d\n", __func__, xlalErrno );
         XLAL_ERROR ( XLAL_EFUNC );
       }
 
       /* ----- if requested, output signal injection parameters into file */
-      if ( fpInjParams && (write_InjParams_to_fp ( fpInjParams, &injParamsDrawn, uvar.dataStartGPS ) != XLAL_SUCCESS ) ) {
+      if ( fpInjParams && (write_InjParams_to_fp ( fpInjParams, &injParamsDrawn, uvar.dataStartGPS, 0, 0 ) ) != XLAL_SUCCESS ) { // options outputMmunuX and numDetectors not supported here, so pass defaults to deactivate them
         XLAL_ERROR ( XLAL_EFUNC );
       } /* if fpInjParams & failure*/
 
 
       /* ----- add meta-info on current transient-CW candidate */
-      transientCandidate_t cand = empty_transientCandidate;
+      transientCandidate_t XLAL_INIT_DECL(cand);
       cand.doppler.Alpha = multiAMBuffer.skypos.longitude;
       cand.doppler.Delta = multiAMBuffer.skypos.latitude;
       cand.windowRange   = cfg.transientSearchRange;
@@ -342,7 +338,7 @@ int main(int argc,char *argv[])
         {
           transientFstatMap_t *FtotalMap;
           /* prepare special window to cover all the data with one F-stat calculation == Ftotal */
-          transientWindowRange_t winRangeAll = empty_transientWindowRange;
+          transientWindowRange_t XLAL_INIT_DECL(winRangeAll);
           winRangeAll.type = TRANSIENT_NONE;
 
           BOOLEAN useFReg = false;
@@ -697,12 +693,9 @@ XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar )
     XLALPrintError ("%s: Failed to get site-info for detector '%s'\n", __func__, uvar->IFO );
     XLAL_ERROR ( XLAL_EFUNC );
   }
-  MultiLALDetector *multiDet;
-  if ( (multiDet = XLALCreateMultiLALDetector ( 1 )) == NULL ) {   /* currently only implemented for single-IFO case */
-    XLALPrintError ("%s: XLALCreateMultiLALDetector(1) failed with errno=%d\n", __func__, xlalErrno );
-    XLAL_ERROR ( XLAL_EFUNC );
-  }
-  multiDet->data[0] = (*site); 	/* copy! */
+  MultiLALDetector multiDet;
+  multiDet.length = 1;
+  multiDet.sites[0] = (*site); 	/* copy! */
   XLALFree ( site );
 
   /* init timestamps vector covering observation time */
@@ -728,22 +721,19 @@ XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar )
     }
 
   /* get detector states */
-  if ( (cfg->multiDetStates = XLALGetMultiDetectorStates ( multiTS, multiDet, edat, 0.5 * uvar->TAtom )) == NULL ) {
+  if ( (cfg->multiDetStates = XLALGetMultiDetectorStates ( multiTS, &multiDet, edat, 0.5 * uvar->TAtom )) == NULL ) {
     XLALPrintError ( "%s: XLALGetMultiDetectorStates() failed.\n", __func__ );
     XLAL_ERROR ( XLAL_EFUNC );
   }
 
   /* get rid of all temporary memory allocated for this step */
-  XLALDestroyMultiLALDetector ( multiDet );
-  XLALFree(edat->ephemE);
-  XLALFree(edat->ephemS);
-  XLALFree ( edat );
+  XLALDestroyEphemerisData ( edat );
   XLALDestroyMultiTimestamps ( multiTS );
   multiTS = NULL;
 
 
   /* ---------- initialize transient window ranges, for injection ... ---------- */
-  transientWindowRange_t InjectRange = empty_transientWindowRange;
+  transientWindowRange_t XLAL_INIT_DECL(InjectRange);
   int twtype;
   XLAL_CHECK ( (twtype = XLALParseTransientWindowName ( uvar->injectWindow_type )) >= 0, XLAL_EFUNC );
   InjectRange.type = twtype;
@@ -777,7 +767,7 @@ XLALInitCode ( ConfigVariables *cfg, const UserInput_t *uvar )
   cfg->transientInjectRange = InjectRange;
 
   /* ---------- ... and for search -------------------- */
-  transientWindowRange_t SearchRange = empty_transientWindowRange;
+  transientWindowRange_t XLAL_INIT_DECL(SearchRange);
   XLAL_CHECK ( (twtype = XLALParseTransientWindowName ( uvar->searchWindow_type )) >= 0, XLAL_EFUNC );
   SearchRange.type = twtype;
 
