@@ -124,6 +124,7 @@
  */
 
 #include <lal/LALStdlib.h>
+#include <lal/LogPrintf.h>
 
 /* Error codes and messages */
 
@@ -394,16 +395,14 @@ int main(int argc,char *argv[]) {
   /* check that LAL header and library versions are consistent */
   if (
       strcmp(lalVersion,LAL_VERSION) ||
-      strcmp(lalConfigureArgs,LAL_CONFIGURE_ARGS) ||
-      strcmp(lalConfigureDate,LAL_CONFIGURE_DATE) ||
-      fabs(lalVersionMajor-LAL_VERSION_MAJOR)>1.e-3 ||
-      fabs(lalVersionMinor-LAL_VERSION_MINOR)>1.e-3
+      (lalVersionMajor != LAL_VERSION_MAJOR ) ||
+      ( lalVersionMinor != LAL_VERSION_MINOR )
       ) {
     error( "Mismatch between compile time header versions and run-time library version:\n");
-    error( "LAL Version: %s\nMajor Version: %d\nMinor Version: %d\nConfig Args: %s\nBuild Date: %s\n",
-	    lalVersion,lalVersionMajor,lalVersionMinor,lalConfigureArgs,lalConfigureDate);
-    error( "LAL Headers: %s\nMajor Version: %d\nMinor Version: %d\nConfig Args: %s\nBuild Date: %s\n",
-	    LAL_VERSION, LAL_VERSION_MAJOR, LAL_VERSION_MINOR, LAL_CONFIGURE_ARGS, LAL_CONFIGURE_DATE);
+    error( "LAL Version: %s\nMajor Version: %d\nMinor Version: %d\n",
+	    lalVersion,lalVersionMajor,lalVersionMinor);
+    error( "LAL Headers: %s\nMajor Version: %d\nMinor Version: %d\n",
+	    LAL_VERSION, LAL_VERSION_MAJOR, LAL_VERSION_MINOR);
     exit(1);
   }
 
@@ -544,10 +543,7 @@ int main(int argc,char *argv[]) {
 
   if (lalDebugLevel >= 3)
     {
-      FILE *fp;
-      fp = fopen ("debug_phi_v2.dat", "w");
-      write_timeSeriesR8 (fp, cgwOutput.phi);
-      fclose (fp);
+      XLALdumpREAL8TimeSeries ("debug_phi_v2.dat", cgwOutput.phi);
     }
 
 
@@ -569,12 +565,9 @@ int main(int argc,char *argv[]) {
 
     if (lalDebugLevel >= 3)
       {
-	FILE *fp;
 	CHAR fname[512];
 	sprintf (fname, "Tseries_v2_%05d.dat", iSFT);
-	fp = fopen (fname, "w");
-	write_timeSeriesR4 (fp, timeSeries);
-	fclose (fp);
+	XLALdumpREAL4TimeSeries (fname, timeSeries);
       }
 
     /*if you want noise, make it and add to timeseries */
