@@ -347,8 +347,6 @@ int parseR8(FILE *fp, const char* vname, REAL8 *data);
 int parseI4(FILE *fp, const char* vname, INT4 *data);
 void usage(FILE *fp);
 
-extern void write_timeSeriesR4 (FILE *fp, const REAL4TimeSeries *series);
-
 /* Like perror() but takes variable numbers of arguments and includes
    program name*/
 void syserror(const char *fmt, ...){
@@ -404,16 +402,14 @@ int main(int argc,char *argv[]) {
   /* check that LAL header and library versions are consistent */
   if (
       strcmp(lalVersion,LAL_VERSION) ||
-      strcmp(lalConfigureArgs,LAL_CONFIGURE_ARGS) ||
-      strcmp(lalConfigureDate,LAL_CONFIGURE_DATE) ||
-      fabs(lalVersionMajor-LAL_VERSION_MAJOR)>1.e-3 ||
-      fabs(lalVersionMinor-LAL_VERSION_MINOR)>1.e-3
+      ( lalVersionMajor != LAL_VERSION_MAJOR ) ||
+      ( lalVersionMinor != LAL_VERSION_MINOR )
       ) {
     error( "Mismatch between compile time header versions and run-time library version:\n");
-    error( "LAL Version: %s\nMajor Version: %d\nMinor Version: %d\nConfig Args: %s\nBuild Date: %s\n",
-	    lalVersion,lalVersionMajor,lalVersionMinor,lalConfigureArgs,lalConfigureDate);
-    error( "LAL Headers: %s\nMajor Version: %d\nMinor Version: %d\nConfig Args: %s\nBuild Date: %s\n",
-	    LAL_VERSION, LAL_VERSION_MAJOR, LAL_VERSION_MINOR, LAL_CONFIGURE_ARGS, LAL_CONFIGURE_DATE);
+    error( "LAL Version: %s\nMajor Version: %d\nMinor Version: %d\n",
+	    lalVersion,lalVersionMajor,lalVersionMinor);
+    error( "LAL Headers: %s\nMajor Version: %d\nMinor Version: %d\n",
+	    LAL_VERSION, LAL_VERSION_MAJOR, LAL_VERSION_MINOR);
     exit(1);
   }
 
