@@ -33,11 +33,15 @@ extern "C" {
 /* likelihood function */
 REAL8 pulsar_log_likelihood( LALInferenceVariables *vars, 
                              LALInferenceIFOData *data,
-                             LALInferenceTemplateFunction get_pulsar_model );
+                             LALInferenceModel *get_pulsar_model );
+
+/* noise only likelihood */
+REAL8 noise_only_likelihood( LALInferenceRunState *runState );
 
 /* prior function */
-REAL8 priorFunction( LALInferenceRunState *runState, 
-                     LALInferenceVariables *params );
+REAL8 priorFunction( LALInferenceRunState *runState,
+		     LALInferenceVariables *params,
+		     LALInferenceModel *mode );
 
 /* check params are within prior range */
 UINT4 in_range( LALInferenceVariables *priors, LALInferenceVariables *params );
