@@ -7,11 +7,10 @@
  */
 
 #include "ppe_models.h"
+#include <lal/CWFastMath.h>
 
 #define SQUARE(x) ( (x) * (x) );
 
-static BinaryPulsarParams empty_BinaryPulsarParams;
-
 /******************************************************************************/
 /*                            MODEL FUNCTIONS                                 */
 /******************************************************************************/
@@ -25,123 +24,124 @@ static BinaryPulsarParams empty_BinaryPulsarParams;
  *
  * Note: Any additional models should be added into this function.
  *
+ * \param model [in] The model structure hold model information and current parameter info
  * \param data [in] The data structure hold data and current parameter info
  *
  * \sa rescale_parameter
  * \sa pulsar_model
  */
-void get_pulsar_model( LALInferenceIFOData *data ){
-  BinaryPulsarParams pars = empty_BinaryPulsarParams; /* initialise as empty */
+void get_pulsar_model( LALInferenceModel *model ){
+  BinaryPulsarParams XLAL_INIT_DECL(pars); /* initialise as empty */
 
   /* set model parameters (including rescaling) */
-  //pars.h0 = rescale_parameter( data, "h0" );
-  pars.cosiota = rescale_parameter( data, "cosiota" );
+  //pars.h0 = rescale_parameter( model, model->ifo, "h0" );
+  pars.cosiota = rescale_parameter( model, model->ifo, "cosiota" );
 
   /* check whether new psi-phi0 coordinates are used */
-  //if ( LALInferenceCheckVariable( data->modelParams, "psiprime" ) &&
-  //     LALInferenceCheckVariable( data->modelParams, "phi0prime" ) ){
-  //  REAL8 phi0prime = rescale_parameter( data, "phi0prime" );
-  //  REAL8 psiprime = rescale_parameter( data, "psiprime" );
+  //if ( LALInferenceCheckVariable( model->params, "psiprime" ) &&
+  //     LALInferenceCheckVariable( model->params, "phi0prime" ) ){
+  //  REAL8 phi0prime = rescale_parameter( model, model->ifo, "phi0prime" );
+  //  REAL8 psiprime = rescale_parameter( model, model->ifo, "psiprime" );
 
   //  /* convert phi0' and psi' into phi0 and psi */
   //  inverse_phi0_psi_transform( phi0prime, psiprime, &pars.phi0, &pars.psi );
   //}
   //else{
-  pars.psi = rescale_parameter( data, "psi" );
-  //  pars.phi0 = rescale_parameter( data, "phi0" );
+  pars.psi = rescale_parameter( model, model->ifo, "psi" );
+  //  pars.phi0 = rescale_parameter( model, model->ifo, "phi0" );
   //}
 
-  if( LALInferenceCheckVariable( data->dataParams, "jones-model" ) ){
+  if( LALInferenceCheckVariable( model->ifo->params, "jones-model" ) ){
     /* use parameterisation from Ian Jones's original model */
-    pars.I21 = rescale_parameter( data, "I21" );
-    pars.I31 = rescale_parameter( data, "I31" );
-    pars.lambda = rescale_parameter( data, "lambda" );
-    pars.costheta = rescale_parameter( data, "costheta" );
-    pars.phi0 = rescale_parameter( data, "phi0" );
+    pars.I21 = rescale_parameter( model, model->ifo, "I21" );
+    pars.I31 = rescale_parameter( model, model->ifo, "I31" );
+    pars.lambda = rescale_parameter( model, model->ifo, "lambda" );
+    pars.costheta = rescale_parameter( model, model->ifo, "costheta" );
+    pars.phi0 = rescale_parameter( model, model->ifo, "phi0" );
 
     invert_source_params( &pars );
   }
   else{
-    pars.C21 = rescale_parameter( data, "C21" );
-    pars.C22 = rescale_parameter( data, "C22" );
-    pars.phi21 = rescale_parameter( data, "phi21" );
+    pars.C21 = rescale_parameter( model, model->ifo, "C21" );
+    pars.C22 = rescale_parameter( model, model->ifo, "C22" );
+    pars.phi21 = rescale_parameter( model, model->ifo, "phi21" );
 
-    if( LALInferenceCheckVariable( data->dataParams, "biaxial" ) ){
+    if( LALInferenceCheckVariable( model->ifo->params, "biaxial" ) ){
       /* use complex amplitude parameterisation, but set up for a biaxial star */
       pars.phi22 = 2.*pars.phi21;
     }
     else{
-      pars.phi22 = rescale_parameter( data, "phi22" );
+      pars.phi22 = rescale_parameter( model, model->ifo, "phi22" );
     }
   }
 
   /* set the potentially variable parameters */
-  pars.pepoch = rescale_parameter( data, "pepoch" );
-  pars.posepoch = rescale_parameter( data, "posepoch" );
+  pars.pepoch = rescale_parameter( model, model->ifo, "pepoch" );
+  pars.posepoch = rescale_parameter( model, model->ifo, "posepoch" );
 
-  pars.ra = rescale_parameter( data, "ra" );
-  pars.pmra = rescale_parameter( data, "pmra" );
-  pars.dec = rescale_parameter( data, "dec" );
-  pars.pmdec = rescale_parameter( data, "pmdec" );
+  pars.ra = rescale_parameter( model, model->ifo, "ra" );
+  pars.pmra = rescale_parameter( model, model->ifo, "pmra" );
+  pars.dec = rescale_parameter( model, model->ifo, "dec" );
+  pars.pmdec = rescale_parameter( model, model->ifo, "pmdec" );
 
-  pars.f0 = rescale_parameter( data, "f0" );
-  pars.f1 = rescale_parameter( data, "f1" );
-  pars.f2 = rescale_parameter( data, "f2" );
-  pars.f3 = rescale_parameter( data, "f3" );
-  pars.f4 = rescale_parameter( data, "f4" );
-  pars.f5 = rescale_parameter( data, "f5" );
+  pars.f0 = rescale_parameter( model, model->ifo, "f0" );
+  pars.f1 = rescale_parameter( model, model->ifo, "f1" );
+  pars.f2 = rescale_parameter( model, model->ifo, "f2" );
+  pars.f3 = rescale_parameter( model, model->ifo, "f3" );
+  pars.f4 = rescale_parameter( model, model->ifo, "f4" );
+  pars.f5 = rescale_parameter( model, model->ifo, "f5" );
 
   /* speed of GWs as a fraction of speed of light LAL_C_SI */
-  pars.cgw = rescale_parameter( data, "cgw" );
+  pars.cgw = rescale_parameter( model, model->ifo, "cgw" );
 
   /* check if there are binary parameters */
-  if( LALInferenceCheckVariable(data->modelParams, "model") ){
+  if( LALInferenceCheckVariable(model->params, "model") ){
     /* binary system model - NOT pulsar model */
-    pars.model = *(CHAR**)LALInferenceGetVariable( data->modelParams, "model" );
+    pars.model = *(CHAR**)LALInferenceGetVariable( model->params, "model" );
 
-    pars.e = rescale_parameter( data, "e" );
-    pars.w0 = rescale_parameter( data, "w0" );
-    pars.Pb = rescale_parameter( data, "Pb" );
-    pars.x = rescale_parameter( data, "x" );
-    pars.T0 = rescale_parameter( data, "T0" );
+    pars.e = rescale_parameter( model, model->ifo, "e" );
+    pars.w0 = rescale_parameter( model, model->ifo, "w0" );
+    pars.Pb = rescale_parameter( model, model->ifo, "Pb" );
+    pars.x = rescale_parameter( model, model->ifo, "x" );
+    pars.T0 = rescale_parameter( model, model->ifo, "T0" );
 
-    pars.e2 = rescale_parameter( data, "e2" );
-    pars.w02 = rescale_parameter( data, "w02" );
-    pars.Pb2 = rescale_parameter( data, "Pb2" );
-    pars.x2 = rescale_parameter( data, "x2" );
-    pars.T02 = rescale_parameter( data, "T02" );
+    pars.e2 = rescale_parameter( model, model->ifo, "e2" );
+    pars.w02 = rescale_parameter( model, model->ifo, "w02" );
+    pars.Pb2 = rescale_parameter( model, model->ifo, "Pb2" );
+    pars.x2 = rescale_parameter( model, model->ifo, "x2" );
+    pars.T02 = rescale_parameter( model, model->ifo, "T02" );
 
-    pars.e3 = rescale_parameter( data, "e3" );
-    pars.w03 = rescale_parameter( data, "w03" );
-    pars.Pb3 = rescale_parameter( data, "Pb3" );
-    pars.x3 = rescale_parameter( data, "x3" );
-    pars.T03 = rescale_parameter( data, "T03" );
+    pars.e3 = rescale_parameter( model, model->ifo, "e3" );
+    pars.w03 = rescale_parameter( model, model->ifo, "w03" );
+    pars.Pb3 = rescale_parameter( model, model->ifo, "Pb3" );
+    pars.x3 = rescale_parameter( model, model->ifo, "x3" );
+    pars.T03 = rescale_parameter( model, model->ifo, "T03" );
 
-    pars.xpbdot = rescale_parameter( data, "xpbdot" );
-    pars.eps1 = rescale_parameter( data, "eps1" );
-    pars.eps2 = rescale_parameter( data, "eps2" );
-    pars.eps1dot = rescale_parameter( data, "eps1dot" );
-    pars.eps2dot = rescale_parameter( data, "eps2dot" );
-    pars.Tasc = rescale_parameter( data, "Tasc" );
+    pars.xpbdot = rescale_parameter( model, model->ifo, "xpbdot" );
+    pars.eps1 = rescale_parameter( model, model->ifo, "eps1" );
+    pars.eps2 = rescale_parameter( model, model->ifo, "eps2" );
+    pars.eps1dot = rescale_parameter( model, model->ifo, "eps1dot" );
+    pars.eps2dot = rescale_parameter( model, model->ifo, "eps2dot" );
+    pars.Tasc = rescale_parameter( model, model->ifo, "Tasc" );
 
-    pars.wdot = rescale_parameter( data, "wdot" );
-    pars.gamma = rescale_parameter( data, "gamma" );
-    pars.Pbdot = rescale_parameter( data, "Pbdot" );
-    pars.xdot = rescale_parameter( data, "xdot" );
-    pars.edot = rescale_parameter( data, "edot" );
+    pars.wdot = rescale_parameter( model, model->ifo, "wdot" );
+    pars.gamma = rescale_parameter( model, model->ifo, "gamma" );
+    pars.Pbdot = rescale_parameter( model, model->ifo, "Pbdot" );
+    pars.xdot = rescale_parameter( model, model->ifo, "xdot" );
+    pars.edot = rescale_parameter( model, model->ifo, "edot" );
 
-    pars.s = rescale_parameter( data, "s" );
-    pars.dr = rescale_parameter( data, "dr" );
-    pars.dth = rescale_parameter( data, "dth" );
-    pars.a0 = rescale_parameter( data, "a0" );
-    pars.b0 = rescale_parameter( data, "b0" );
+    pars.s = rescale_parameter( model, model->ifo, "s" );
+    pars.dr = rescale_parameter( model, model->ifo, "dr" );
+    pars.dth = rescale_parameter( model, model->ifo, "dth" );
+    pars.a0 = rescale_parameter( model, model->ifo, "a0" );
+    pars.b0 = rescale_parameter( model, model->ifo, "b0" );
 
-    pars.M = rescale_parameter( data, "M" );
-    pars.m2 = rescale_parameter( data, "m2" );
+    pars.M = rescale_parameter( model, model->ifo, "M" );
+    pars.m2 = rescale_parameter( model, model->ifo, "m2" );
   }
 
   /* now get pulsar model */
-  pulsar_model( pars, data );
+  pulsar_model( pars, model->ifo );
 
 }
 
@@ -151,12 +151,13 @@ void get_pulsar_model( LALInferenceIFOData *data ){
  *
  * This function will rescale a parameter to its true value using the scale factor and minimum scale value.
  *
- * \param data [in] data structure containing parameter information
+ * \param model [in] model structure containing parameter information
+ * \param ifo [in] ifo model structure containing ifo-dependent parameter information
  * \param parname [in] name of the parameter requiring rescaling
  *
  * \return Rescaled parameter value
  */
-REAL8 rescale_parameter( LALInferenceIFOData *data, const CHAR *parname ){
+REAL8 rescale_parameter( LALInferenceModel *model, LALInferenceIFOModel *ifo, const CHAR *parname ){
   REAL8 par = 0., scale = 0., offset = 0.;
   CHAR scaleName[VARNAME_MAX] = "";
   CHAR offsetName[VARNAME_MAX] = "";
@@ -164,10 +165,10 @@ REAL8 rescale_parameter( LALInferenceIFOData *data, const CHAR *parname ){
   sprintf(scaleName, "%s_scale", parname);
   sprintf(offsetName, "%s_scale_min", parname);
 
-  scale = *(REAL8*)LALInferenceGetVariable( data->dataParams, scaleName );
-  offset = *(REAL8*)LALInferenceGetVariable( data->dataParams, offsetName );
+  scale = *(REAL8*)LALInferenceGetVariable( ifo->params, scaleName );
+  offset = *(REAL8*)LALInferenceGetVariable( ifo->params, offsetName );
 
-  par = *(REAL8*)LALInferenceGetVariable( data->modelParams, parname );
+  par = *(REAL8*)LALInferenceGetVariable( model->params, parname );
 
   par = par*scale + offset;
 
@@ -187,33 +188,32 @@ REAL8 rescale_parameter( LALInferenceIFOData *data, const CHAR *parname ){
  * Firstly the time varying amplitude of the signal will be calculated based on the antenna pattern and amplitude
  * parameters. Then, if searching over phase parameters, the phase evolution of the signal will be calculated. The
  * difference between the new phase model, \f$\phi(t)_n\f$, and that used to heterodyne the data, \f$\phi(t)_h\f$,
- * (stored in \c data->timeData->data) will be calculated and the complex signal model, \f$M\f$, modified accordingly:
+ * (stored in \c ifo->timeData->data) will be calculated and the complex signal model, \f$M\f$, modified accordingly:
  * \f[
  * M'(t) = M(t)\exp{i(-(\phi(t)_n - \phi(t)_h))}.
  * \f]
  *
  * \param params [in] A \c BinaryPulsarParams structure containing the model parameters
- * \param data [in] The data structure containing the detector data and additional info
+ * \param ifo [in] The ifo model structure containing the detector paramters and buffers
  *
  * \sa get_amplitude_model
- * \sa get_amplitude_model
  * \sa get_phase_model
  */
-void pulsar_model( BinaryPulsarParams params, LALInferenceIFOData *data ){
+void pulsar_model( BinaryPulsarParams params, LALInferenceIFOModel *ifo ){
   INT4 i = 0, length = 0;
   UINT4 j = 0;
   REAL8 mm = 0.;
 
   /* check model type to get amplitude model */
-  // modeltype = *(CHAR**)LALInferenceGetVariable( data->dataParams, "modeltype" );
+  // modeltype = *(CHAR**)LALInferenceGetVariable( ifo->params, "modeltype" );
 
-  get_amplitude_model( params, data );
+  get_amplitude_model( params, ifo );
 
   /* if ( !strcmp( modeltype, "triaxial" ) ){
-    get_triaxial_amplitude_model( params, data );
+    get_triaxial_amplitude_model( params, ifo );
   }
   else if ( !strcmp( modeltype, "pinsf" ) ){
-    get_pinsf_amplitude_model( params, data );
+    get_pinsf_amplitude_model( params, ifo );
   } */
   /* ADD NEW MODELS HERE */
   /* else{
@@ -223,10 +223,10 @@ void pulsar_model( BinaryPulsarParams params, LALInferenceIFOData *data ){
 
   /* get difference in phase for f component and perform extra heterodyne */
   REAL8Vector *freqFactors = NULL;
-  freqFactors = *(REAL8Vector **)LALInferenceGetVariable( data->dataParams, "freqfactors" );
+  freqFactors = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "freqfactors" );
 
-  if( LALInferenceCheckVariable( data->dataParams, "mismatch" ) ){
-    mm = *(REAL8 *)LALInferenceGetVariable( data->dataParams, "mismatch" );
+  if( LALInferenceCheckVariable( ifo->params, "mismatch" ) ){
+    mm = *(REAL8 *)LALInferenceGetVariable( ifo->params, "mismatch" );
   }
 
   for( j = 0; j < freqFactors->length; j++ ){
@@ -235,21 +235,23 @@ void pulsar_model( BinaryPulsarParams params, LALInferenceIFOData *data ){
 
     /* move data pointer along one as one iteration of the model is held over j data structures, moved this from bottom
      * of loop so actioned for 2nd run through the loop.*/
-    if ( j > 0 ) { data = data->next; }
+    if ( j > 0 ) { ifo = ifo->next; }
 
-    length = data->compModelData->data->length;
-    /* the timeData vector within the LALIFOData structure contains the phase calculated using the initial (heterodyne)
+    length = ifo->compTimeSignal->data->length;
+    /* the timeData vector within the LALIFOModel structure contains the phase calculated using the initial (heterodyne)
      * values of the phase parameters */
     if ( varyphase ){
       /* check whether to recompute the full phase or not */
-      if( LALInferenceCheckVariable( data->dataParams, "downsampled_times" ) ){
+      if( LALInferenceCheckVariable( ifo->params, "downsampled_times" ) ){
+        /* FIXME: This section needs to be thoroughly checked to make sure that it
+         * is doing what it is supposed to! At the moment I think it is wrong. */
         REAL8Vector *dsdphi1 = NULL, *dsdphi2 = NULL;
         LIGOTimeGPSVector *downst =
-          *(LIGOTimeGPSVector **)LALInferenceGetVariable( data->dataParams, "downsampled_times" );
+          *(LIGOTimeGPSVector **)LALInferenceGetVariable( ifo->params, "downsampled_times" );
 
         /* get the previous downsampled phase if it exists */
-        if ( LALInferenceCheckVariable( data->dataParams, "ds_phase" ) ){
-          dsdphi1 = *(REAL8Vector **)LALInferenceGetVariable( data->dataParams, "ds_phase" );
+        if ( LALInferenceCheckVariable( ifo->params, "ds_phase" ) ){
+          dsdphi1 = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "ds_phase" );
         }
         else{
           XLALPrintError("Error, downsampled phase does not exist\n");
@@ -257,7 +259,7 @@ void pulsar_model( BinaryPulsarParams params, LALInferenceIFOData *data ){
         }
 
         /* get the downsampled phase for the current parameters */
-        dsdphi2 = get_phase_model( params, data, freqFactors->data[j], 1 );
+        dsdphi2 = get_phase_model( params, ifo, freqFactors->data[j], 1 );
 
         /* work out phase mismatch (if any value in dsdphi1 is not zero it means
            ds_phase has been set) */
@@ -276,20 +278,20 @@ void pulsar_model( BinaryPulsarParams params, LALInferenceIFOData *data ){
 
       /* reheterodyne with the phase */
       if ( !nohet ){
-        if ( (dphi = get_phase_model( params, data, freqFactors->data[j], 0 )) != NULL ){
+        if ( (dphi = get_phase_model( params, ifo, freqFactors->data[j], 0 )) != NULL ){
           for( i=0; i<length; i++ ){
             COMPLEX16 M;
             REAL8 dphit;
             COMPLEX16 expp;
 
-            dphit = -fmod(dphi->data[i] - data->timeData->data->data[i], 1.);
+            dphit = fmod(dphi->data[i] - ifo->timeData->data->data[i], 1.);
 
             expp = cexp( LAL_TWOPI * I * dphit );
 
-            M = data->compModelData->data->data[i];
+            M = ifo->compTimeSignal->data->data[i];
 
             /* heterodyne */
-            data->compModelData->data->data[i] = M * expp;
+            ifo->compTimeSignal->data->data[i] = M * expp;
           }
 
           XLALDestroyREAL8Vector( dphi );
@@ -321,8 +323,8 @@ void pulsar_model( BinaryPulsarParams params, LALInferenceIFOData *data ){
  * The solar system barycentre delay does not have to be explicitly computed for every time stamp passed to it, but
  * instead will just use linear interpolation within a time range set by \c interptime.
  *
- * \param params [in] A set of pulsar parameters
- * \param data [in] The data structure containing the detector data and additional info
+  * \param params [in] A set of pulsar parameters
+ * \param ifo [in] The ifo model structure containing the detector parameters and buffers
  * \param freqFactor [in] the multiplicative factor on the pulsar frequency for a particular model
  * \param downsampled *UNDOCUMENTED*
  *
@@ -331,7 +333,7 @@ void pulsar_model( BinaryPulsarParams params, LALInferenceIFOData *data ){
  * \sa get_ssb_delay
  * \sa get_bsb_delay
  */
-REAL8Vector *get_phase_model( BinaryPulsarParams params, LALInferenceIFOData *data, REAL8 freqFactor,
+REAL8Vector *get_phase_model( BinaryPulsarParams params, LALInferenceIFOModel *ifo, REAL8 freqFactor,
                               UINT4 downsampled ){
   INT4 i = 0, length = 0;
 
@@ -343,19 +345,19 @@ REAL8Vector *get_phase_model( BinaryPulsarParams params, LALInferenceIFOData *da
 
   /* check if we want to calculate the phase at a the downsampled rate */
   if ( downsampled ){
-    if( LALInferenceCheckVariable( data->dataParams, "downsampled_times" ) ){
+    if( LALInferenceCheckVariable( ifo->params, "downsampled_times" ) ){
       datatimes = *(LIGOTimeGPSVector **)LALInferenceGetVariable(
-        data->dataParams, "downsampled_times" );
+        ifo->params, "downsampled_times" );
     }
     else{
       fprintf(stderr, "Error, no downsampled time series available\n");
       exit(1);
     }
   }
-  else datatimes = data->dataTimes;
+  else datatimes = ifo->times;
 
   /* if edat is NULL then return a NULL pointer */
-  if( data->ephem == NULL ) return NULL;
+  if( ifo->ephem == NULL ) return NULL;
 
   length = datatimes->length;
 
@@ -364,18 +366,18 @@ REAL8Vector *get_phase_model( BinaryPulsarParams params, LALInferenceIFOData *da
 
   /* get time delays */
   /*Why ==NULL, surely it will equal null if not set to get ssb delays?*/
-  if( (dts = *(REAL8Vector **)LALInferenceGetVariable( data->dataParams, "ssb_delays" )) == NULL || varyskypos == 1 ){
+  if( (dts = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "ssb_delays" )) == NULL || varyskypos == 1 ){
     /* get time delays with an interpolation of interptime (30 mins) */
-    dts = get_ssb_delay( params, datatimes, data->ephem, data->tdat, data->ttype, data->detector, interptime );
+    dts = get_ssb_delay( params, datatimes, ifo->ephem, ifo->tdat, ifo->ttype, ifo->detector, interptime );
   }
 
-  if( (bdts = *(REAL8Vector **)LALInferenceGetVariable( data->dataParams, "bsb_delays" )) == NULL || varybinary == 1 ){
+  if( (bdts = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "bsb_delays" )) == NULL || varybinary == 1 ){
     /* get binary system time delays */
-    bdts = get_bsb_delay( params, datatimes, dts, data->ephem );
+    bdts = get_bsb_delay( params, datatimes, dts, ifo->ephem );
   }
 
   for( i=0; i<length; i++){
-    REAL8 realT = XLALGPSGetREAL8( &data->dataTimes->data[i] ); /*time of data*/
+    REAL8 realT = XLALGPSGetREAL8( &ifo->times->data[i] ); /*time of data*/
 
     T0 = params.pepoch; /*time of ephem info*/
 
@@ -384,7 +386,7 @@ REAL8Vector *get_phase_model( BinaryPulsarParams params, LALInferenceIFOData *da
     if ( params.model != NULL ) { deltat = DT + dts->data[i] + bdts->data[i]; }
     else { deltat = DT + dts->data[i]; }
 
-    deltat /= (1.-params.cgw); /* correct for speed of GW compared to speed of light */
+    deltat /= params.cgw; /* correct for speed of GW compared to speed of light */
 
     /* work out phase */
     deltat2 = deltat*deltat;
@@ -397,10 +399,10 @@ REAL8Vector *get_phase_model( BinaryPulsarParams params, LALInferenceIFOData *da
   }
 
   /* free memory */
-  if ( !LALInferenceCheckVariable( data->dataParams, "ssb_delays") || varyskypos == 1 )
+  if ( !LALInferenceCheckVariable( ifo->params, "ssb_delays") || varyskypos == 1 )
     XLALDestroyREAL8Vector( dts );
 
-  if ( !LALInferenceCheckVariable( data->dataParams, "bsb_delays") || varybinary == 1 )
+  if ( !LALInferenceCheckVariable( ifo->params, "bsb_delays") || varybinary == 1 )
     XLALDestroyREAL8Vector( bdts );
 
   return phis;
@@ -451,6 +453,10 @@ REAL8Vector *get_ssb_delay( BinaryPulsarParams pars, LIGOTimeGPSVector *datatime
   bary = (BarycenterInput*)XLALCalloc( 1, sizeof(BarycenterInput) );
   memcpy( &bary->site, detector, sizeof(LALDetector) );
 
+  bary->site.location[0] /= LAL_C_SI;
+  bary->site.location[1] /= LAL_C_SI;
+  bary->site.location[2] /= LAL_C_SI;
+
   bary->alpha = pars.ra;
   bary->delta = pars.dec;
 
@@ -581,11 +587,11 @@ REAL8Vector *get_bsb_delay( BinaryPulsarParams pars, LIGOTimeGPSVector *datatime
  * closest points within the lookup table to the required values.
  *
  * \param pars [in] A set of pulsar parameters
- * \param data [in] The data parameters giving information on the data and detector
+ * \param ifo [in] The ifo parameters giving information on the data and detector
  *
  * DEPRECATED: use \c get_amplitude_model instead.
  */
-void get_triaxial_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *data ){
+void get_triaxial_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOModel *ifo ){
   INT4 i = 0, length;
 
   REAL8 psteps, tsteps, psv, tsv;
@@ -601,17 +607,17 @@ void get_triaxial_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData
   gsl_matrix *LU_Fplus, *LU_Fcross;
   REAL8Vector *sidDayFrac = NULL;
 
-  length = data->dataTimes->length;
+  length = ifo->times->length;
 
   /* set lookup table parameters */
-  psteps = *(INT4*)LALInferenceGetVariable( data->dataParams, "psiSteps" );
-  tsteps = *(INT4*)LALInferenceGetVariable( data->dataParams, "timeSteps" );
+  psteps = *(INT4*)LALInferenceGetVariable( ifo->params, "psiSteps" );
+  tsteps = *(INT4*)LALInferenceGetVariable( ifo->params, "timeSteps" );
 
-  LU_Fplus = *(gsl_matrix**)LALInferenceGetVariable( data->dataParams, "LU_Fplus" );
-  LU_Fcross = *(gsl_matrix**)LALInferenceGetVariable( data->dataParams, "LU_Fcross" );
+  LU_Fplus = *(gsl_matrix**)LALInferenceGetVariable( ifo->params, "LU_Fplus" );
+  LU_Fcross = *(gsl_matrix**)LALInferenceGetVariable( ifo->params, "LU_Fcross" );
 
   /* get the sidereal time since the initial data point % sidereal day */
-  sidDayFrac = *(REAL8Vector**)LALInferenceGetVariable( data->dataParams, "siderealDay" );
+  sidDayFrac = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "siderealDay" );
 
   expiphi = cexp( I * pars.phi0 );
 
@@ -669,7 +675,7 @@ void get_triaxial_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData
       + cross11*psiScaled*timeScaled;
 
     /* create the complex signal amplitude model */
-    data->compModelData->data->data[i] = plus*Xpexpphi - I*cross*Xcexpphi;
+    ifo->compTimeSignal->data->data[i] = plus*Xpexpphi - I*cross*Xcexpphi;
   }
 }
 
@@ -682,8 +688,8 @@ void get_triaxial_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData
  * pinning axis of its pinned superfluid component.
  *
  * Unlike the standard triaxial model, this model has emission at f and 2f, therefore this model function processes two
- * sets of data per detector. In this model the \f$\phi_0\f$ parameter is the initial rotational phase, rather than the
- * GW phase as in the triaxial model.
+ * sets of data per detector. In this model the \f$\phi_0\f$ parameter is the initial phase for the \f$l=m=2\f$ harmonic
+ * (i.e. equivalent to the phase at 2f for the triaxial model).
  *
  * As for the standard triaxial model, the antenna pattern functions are contained in a 2D lookup table, so within this
  * function the correct value for the given time and \f$\psi\f$ are interpolated from this lookup table using bilinear
@@ -696,11 +702,11 @@ void get_triaxial_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData
  * closest points within the lookup table to the required values.
  *
  * \param pars [in] A set of pulsar parameters
- * \param data [in] The data parameters giving information on the data and detector
+ * \param ifo  [in] The ifo model containing detector-specific parameters
  *
  * DEPRECATED: use \c get_amplitude_model instead.
  */
-void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *data ){
+void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOModel *ifo ){
   INT4 i = 0, length;
 
   REAL8 psteps, tsteps, psv, tsv;
@@ -725,19 +731,19 @@ void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *da
   REAL8Vector *sidDayFrac2 = NULL;
 
   /* set lookup table parameters */
-  psteps = *(INT4*)LALInferenceGetVariable( data->dataParams, "psiSteps" );
-  tsteps = *(INT4*)LALInferenceGetVariable( data->dataParams, "timeSteps" );
+  psteps = *(INT4*)LALInferenceGetVariable( ifo->params, "psiSteps" );
+  tsteps = *(INT4*)LALInferenceGetVariable( ifo->params, "timeSteps" );
 
-  LU_Fplus = *(gsl_matrix**)LALInferenceGetVariable( data->dataParams, "LU_Fplus" );
-  LU_Fcross = *(gsl_matrix**)LALInferenceGetVariable( data->dataParams, "LU_Fcross");
+  LU_Fplus = *(gsl_matrix**)LALInferenceGetVariable( ifo->params, "LU_Fplus" );
+  LU_Fcross = *(gsl_matrix**)LALInferenceGetVariable( ifo->params, "LU_Fcross");
   /* get the sidereal time since the initial data point % sidereal day */
-  sidDayFrac1 = *(REAL8Vector**)LALInferenceGetVariable( data->dataParams, "siderealDay" );
+  sidDayFrac1 = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "siderealDay" );
 
-  /* phi0 here is rotational phase not GW phase */
-  ePhi = cexp( pars.phi0 * I );
-  e2Phi = cexp( 2. * pars.phi0 * I );
+  /* phi0 here the GW phase for the l=m=2 mode */
+  ePhi = cexp( 0.5 * pars.phi0 * I );
+  e2Phi = cexp( pars.phi0 * I );
 
-  sin_cos_LUT( &sinlambda, &coslambda, pars.lambda );
+  XLAL_CHECK_VOID( XLALSinCosLUT( &sinlambda, &coslambda, pars.lambda ) == XLAL_SUCCESS, XLAL_EFUNC );
 
   /* f^2 / r */
   f2_r = pars.f0 * pars.f0 / pars.dist;
@@ -773,7 +779,7 @@ void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *da
 
   /*--------------------------------------------------------------------------*/
   /* set model for 1f component */
-  length = data->dataTimes->length;
+  length = ifo->times->length;
 
   for( i=0; i<length; i++ ){
     /* set the time bin for the lookup table */
@@ -806,15 +812,15 @@ void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *da
       + cross11*psiScaled*timeScaled;
 
     /* create the complex signal amplitude model at f */
-    data->compModelData->data->data[i] = ( plus * Xplusf * ePhi * ( A21 - I * B21 ) ) +
+    ifo->compTimeSignal->data->data[i] = ( plus * Xplusf * ePhi * ( A21 - I * B21 ) ) +
                                          ( cross * Xcrossf * ePhi * ( B21 + I * A21 ) );
   }
 
   /*--------------------------------------------------------------------------*/
   /* set model for 2f component */
-  length = data->next->dataTimes->length;
+  length = ifo->next->times->length;
 
-  sidDayFrac2 = *(REAL8Vector**)LALInferenceGetVariable( data->next->dataParams, "siderealDay" );
+  sidDayFrac2 = *(REAL8Vector**)LALInferenceGetVariable( ifo->next->params, "siderealDay" );
 
   for( i=0; i<length; i++ ){
     /* set the time bin for the lookup table */
@@ -847,7 +853,7 @@ void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *da
       + cross11*psiScaled*timeScaled;
 
     /* create the complex signal amplitude model at 2f */
-    data->next->compModelData->data->data[i] = ( plus * Xplus2f * e2Phi * ( A22 - I * B22 ) ) +
+    ifo->next->compTimeSignal->data->data[i] = ( plus * Xplus2f * e2Phi * ( A22 - I * B22 ) ) +
                                                ( cross * Xcross2f * e2Phi * ( B22 + I * A22 ) );
   }
   /*--------------------------------------------------------------------------*/
@@ -874,10 +880,10 @@ void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *da
  * closest points within the lookup table to the required values.
  *
  * \param pars [in] A set of pulsar parameters
- * \param data [in] The data parameters giving information on the data and detector
+ * \param ifo  [in] The ifo model containing detector-specific parameters
  *
  */
-void get_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *data ){
+void get_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOModel *ifo ){
   UINT4 i = 0, j = 0, length;
 
   REAL8 psteps, tsteps, psv, tsv;
@@ -893,13 +899,13 @@ void get_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *data ){
   REAL8Vector *freqFactors = NULL;
 
   /* set lookup table parameters */
-  psteps = *(INT4*)LALInferenceGetVariable( data->dataParams, "psiSteps" );
-  tsteps = *(INT4*)LALInferenceGetVariable( data->dataParams, "timeSteps" );
+  psteps = *(INT4*)LALInferenceGetVariable( ifo->params, "psiSteps" );
+  tsteps = *(INT4*)LALInferenceGetVariable( ifo->params, "timeSteps" );
 
-  LU_Fplus = *(gsl_matrix**)LALInferenceGetVariable( data->dataParams, "LU_Fplus" );
-  LU_Fcross = *(gsl_matrix**)LALInferenceGetVariable( data->dataParams, "LU_Fcross" );
+  LU_Fplus = *(gsl_matrix**)LALInferenceGetVariable( ifo->params, "LU_Fplus" );
+  LU_Fcross = *(gsl_matrix**)LALInferenceGetVariable( ifo->params, "LU_Fcross" );
 
-  freqFactors = *(REAL8Vector**)LALInferenceGetVariable( data->dataParams, "freqfactors" );
+  freqFactors = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "freqfactors" );
 
   psv = LAL_PI / ( psteps - 1. );
   psibinMin = (INT4)floor( ( pars.psi + LAL_PI_2 )/psv );
@@ -918,15 +924,15 @@ void get_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *data ){
     COMPLEX16 expPhi;
     COMPLEX16 Cplus, Ccross;
 
-    if ( !data ){
-      XLALPrintError( "%s: Error... data not defined.\n", __func__ );
+    if ( !ifo ){
+      XLALPrintError( "%s: Error... ifo model not defined.\n", __func__ );
       XLAL_ERROR_VOID( XLAL_EINVAL );
     }
 
     /* get the sidereal time since the initial data point % sidereal day */
-    sidDayFrac = *(REAL8Vector**)LALInferenceGetVariable( data->dataParams, "siderealDay" );
+    sidDayFrac = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "siderealDay" );
 
-    length = data->dataTimes->length;
+    length = ifo->times->length;
 
     /* get the amplitude and phase factors */
     if( freqFactors->data[j] == 1. ){
@@ -978,90 +984,14 @@ void get_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOData *data ){
         + cross11*psiScaled*timeScaled;
 
       /* create the complex signal amplitude model appropriate for the harmonic */
-      data->compModelData->data->data[i] = ( Cplus * plus ) + ( Ccross * cross );
+      ifo->compTimeSignal->data->data[i] = ( Cplus * plus ) + ( Ccross * cross );
     }
 
-    data = data->next;
+    ifo = ifo->next;
   }
 }
 
 
-/**
- * \brief Calculate the natural logarithm of the evidence that the data consists of only Gaussian noise
- * The function will calculate the natural logarithm of the evidence that the data (from one or more detectors) consists
- * of stationary segments/chunks described by a Gaussian with zero mean and unknown variance.
- *
- * The evidence is obtained from the joint likelihood given in \c pulsar_log_likelihood with the model term \f$y\f$ set
- * to zero.
- *
- * \param runState [in] The algorithm run state
- *
- * \return The natural logarithm of the noise only evidence
- */
-REAL8 noise_only_model( LALInferenceRunState *runState ){
-  LALInferenceIFOData *data = runState->data;
-
-  REAL8 logL = 0.0;
-  UINT4 i = 0;
-  INT4 k = 0;
-
-  REAL8Vector *freqFactors = NULL;
-  FILE *fp = NULL;
-  CHAR *Znoisefile = NULL;
-  ProcessParamsTable *ppt;
-  ProcessParamsTable *commandLine = runState->commandLine;
-  /*-----------------------------*/
-  /*get the outfile name*/
-  ppt = LALInferenceGetProcParamVal( commandLine, "--outfile" );
-
-  freqFactors = *(REAL8Vector **)LALInferenceGetVariable( data->dataParams, "freqfactors" );
-
-  /* open the file to output noise evidence (or null signal evidence) for each individual data stream */
-  /* set the Znoise filename to the outfile name with "_Znoise" appended */
-  Znoisefile = XLALStringDuplicate( ppt->value );
-  Znoisefile = XLALStringAppend( Znoisefile, "_Znoise" );
-
-  if( (fp = fopen(Znoisefile, "w")) == NULL ){
-    fprintf(stderr, "Error... cannot open output Znoise file!\n");
-    exit(0);
-  }
-
-  /*calculate the evidence */
-  while ( data ){
-    UINT4Vector *chunkLengths = NULL;
-    REAL8Vector *sumDat = NULL;
-
-    REAL8 chunkLength = 0.;
-    REAL8 logLtmp = 0.;
-
-    chunkLengths = *(UINT4Vector **)LALInferenceGetVariable( data->dataParams,  "chunkLength" );
-    sumDat = *(REAL8Vector **)LALInferenceGetVariable( data->dataParams, "sumData" );
-    /*Sum the logL over the datachunks*/
-    for (i=0; i<chunkLengths->length; i++){
-      chunkLength = (REAL8)chunkLengths->data[i];
-
-      logLtmp -= chunkLength * log(sumDat->data[i]) + LAL_LN2 * (chunkLength-1.) + gsl_sf_lnfact(chunkLength);
-    }
-
-    logL += logLtmp;
-
-    /* output the noise evidence for each data stream for each detector  */
-    fprintf(fp, "%s\t%.3lf\t%.16le\n", data->name, freqFactors->data[k], logLtmp);
-
-    k += 1; /* advance counter now, as freqfactors array index starts at zero.*/
-
-    /* reset k, freqfactor counter once all datastreamns for a detector are done */
-    if( k >= (INT4)freqFactors->length ) { k = 0; }
-
-    data = data->next;
-  }
-
-  fclose(fp);
-
-  return logL;
-}
-
-
 /**
  * \brief Calculate the phase mismatch between two vectors of phases
  *
@@ -1099,7 +1029,7 @@ REAL8 get_phase_mismatch( REAL8Vector *phi1, REAL8Vector *phi2, LIGOTimeGPSVecto
   for( i = 0; i < phi1->length-1; i++ ){
     if ( i == 0 ){
       dp1 = fmod( phi1->data[i] - phi2->data[i], 1. );
-      sin_cos_2PI_LUT( &sp, &cp1, dp1 );
+      XLAL_CHECK_REAL8( XLALSinCos2PiLUT( &sp, &cp1, dp1 ) == XLAL_SUCCESS, XLAL_EFUNC );
     }
     else{
       dp1 = dp2;
@@ -1110,7 +1040,7 @@ REAL8 get_phase_mismatch( REAL8Vector *phi1, REAL8Vector *phi2, LIGOTimeGPSVecto
 
     dt = XLALGPSGetREAL8(&t->data[i+1]) - XLALGPSGetREAL8(&t->data[i]);
 
-    sin_cos_2PI_LUT( &sp, &cp2, dp2 );
+    XLAL_CHECK_REAL8( XLALSinCos2PiLUT( &sp, &cp2, dp2 ) == XLAL_SUCCESS, XLAL_EFUNC );
 
     mismatch += (cp1 + cp2) * dt;
   }
@@ -1288,39 +1218,47 @@ void inverse_phi0_psi_transform( REAL8 phi0prime, REAL8 psiprime, REAL8 *phi0, R
  *
  * Convert the physical source parameters into the amplitude and phase notation given in Eqns
  * 76-79 of LIGO T1200265-v3.
+ *
+ * In this is \c phi0 is the gravitational wave phase for a signal from the l=m=2 mode.
  */
 void invert_source_params( BinaryPulsarParams *params ){
   REAL8 sinlambda, coslambda, sinlambda2, coslambda2, sin2lambda;
   REAL8 theta, sintheta, costheta, costheta2, sintheta2, sin2theta;
   REAL8 phi0 = params->phi0;
 
-  sinlambda = sin( params->lambda );
-  coslambda = cos( params->lambda );
-  sin2lambda = sin( 2. * params->lambda );
-  sinlambda2 = SQUARE( sinlambda );
-  coslambda2 = SQUARE( coslambda );
+  if ( params->h0 != 0.){
+    params->C22 = 0.5 * params->h0;
+    params->phi22 = params->phi0 - LAL_PI;
+    params->phi22 = params->phi22 - LAL_TWOPI*floor(params->phi22/LAL_TWOPI);
+  }
+  else{
+    sinlambda = sin( params->lambda );
+    coslambda = cos( params->lambda );
+    sin2lambda = sin( 2. * params->lambda );
+    sinlambda2 = SQUARE( sinlambda );
+    coslambda2 = SQUARE( coslambda );
 
-  theta = acos( params->costheta );
-  sintheta = sin( theta );
-  costheta = params->costheta;
-  sin2theta = sin( 2. * theta );
-  sintheta2 = SQUARE( sintheta );
-  costheta2 = SQUARE( costheta );
+    theta = acos( params->costheta );
+    sintheta = sin( theta );
+    costheta = params->costheta;
+    sin2theta = sin( 2. * theta );
+    sintheta2 = SQUARE( sintheta );
+    costheta2 = SQUARE( costheta );
 
-  REAL8 A22 = params->I21 * ( sinlambda2 - coslambda2 * costheta2 ) - params->I31 * sintheta2;
-  REAL8 B22 = params->I21 * sin2lambda * costheta;
-  REAL8 A222 = SQUARE( A22 );
-  REAL8 B222 = SQUARE( B22 );
+    REAL8 A22 = params->I21 * ( sinlambda2 - coslambda2 * costheta2 ) - params->I31 * sintheta2;
+    REAL8 B22 = params->I21 * sin2lambda * costheta;
+    REAL8 A222 = SQUARE( A22 );
+    REAL8 B222 = SQUARE( B22 );
 
-  REAL8 A21 = params->I21 * sin2lambda * sintheta;
-  REAL8 B21 = sin2theta * ( params->I21 * coslambda2 - params->I31 );
-  REAL8 A212 = SQUARE( A21 );
-  REAL8 B212 = SQUARE( B21 );
+    REAL8 A21 = params->I21 * sin2lambda * sintheta;
+    REAL8 B21 = sin2theta * ( params->I21 * coslambda2 - params->I31 );
+    REAL8 A212 = SQUARE( A21 );
+    REAL8 B212 = SQUARE( B21 );
 
-  params->C22 = 2.*sqrt( A222 + B222 );
-  params->C21 = 2.*sqrt( A212 + B212 );
+    params->C22 = 2.*sqrt( A222 + B222 );
+    params->C21 = 2.*sqrt( A212 + B212 );
 
-  params->phi22 = fmod( phi0 - atan2( B22, A22 ), LAL_TWOPI );
-  params->phi21 = fmod( ( phi0/2. ) - atan2( B21, A21 ), LAL_TWOPI );
+    params->phi22 = fmod( phi0 - atan2( B22, A22 ), LAL_TWOPI );
+    params->phi21 = fmod( ( phi0/2. ) - atan2( B21, A21 ), LAL_TWOPI );
+  }
 }
-
