@@ -1,7 +1,7 @@
 #!/bin/bash
 
 # this script will be used as part of 'make test' to make sure that the
-# lalapps_heterodyne_pulsar code outputs the correct result. It will run 
+# lalapps_heterodyne_pulsar code outputs the correct result. It will run
 # the code in all its 4 modes and compare the results to standard
 # archived files
 
@@ -37,7 +37,7 @@ PFILE=$PSRNAME.par
 UNITS=TDB
 
 if [ -f $PFILE ]; then
-	rm -f $PFILE
+  rm -f $PFILE
 fi
 
 echo PSR    $PSRNAME > $PFILE
@@ -49,8 +49,8 @@ echo PEPOCH $PEPOCH >> $PFILE
 echo UNITS  $UNITS >> $PFILE
 
 if [ $? != "0" ]; then
-	echo Error writing parameter file!
-	exit 2
+  echo Error writing parameter file!
+  exit 2
 fi
 
 # create slightly offset parameter file (for testing update mode)
@@ -84,55 +84,55 @@ TEPHEM="tdb_2000-2019.dat.gz"
 # get current location
 LOCATION=`pwd`
 if [ $? != "0" ]; then
-	echo Error! Could not set the current path!
-	exit 2
+  echo Error! Could not set the current path!
+  exit 2
 fi
 
 # create a frame cache file in the format used by the code
 
 # check file doesn't already exit
 if [ -f cachefile ]; then
-	rm -f cachefile
+  rm -f cachefile
 fi
 
 # make directory to contain the frames and unpack the tar file
 # first check if it already exists
 if [ -d ${LOCATION}/framedir ]; then
-	rm -f ${LOCATION}/framedir/*
-	rmdir ${LOCATION}/framedir
+  rm -f ${LOCATION}/framedir/*
+  rmdir ${LOCATION}/framedir
 fi
 
 mkdir ${LOCATION}/framedir
 if [ $? != "0" ]; then
-	echo Error. Could not create frame directory
-	exit 2
+  echo Error. Could not create frame directory
+  exit 2
 fi
 
 if [ ! -f $FRAMEFILE ]; then
-	echo Error. Frame file does not exist!
-	exit 2
+  echo Error. Frame file does not exist!
+  exit 2
 fi
 
 FILELIST=$FRAMEFILE
-cp $FILELIST ${LOCATION}/framedir 
+cp $FILELIST ${LOCATION}/framedir
 
 # use make_frame_cache to make a frame cache file
 if [ ! -f ${srcdir}/make_frame_cache ]; then
-	echo Error! make_frame_cache does not exist!
-	exit 2
+  echo Error! make_frame_cache does not exist!
+  exit 2
 fi
 
 ${srcdir}/make_frame_cache --frame-dir ${LOCATION}/framedir --gps-start-time $DATASTART --gps-end-time $DATAEND --output-file cachefile
 if [ $? != "0" ]; then
-	echo Could not create the cache file!
-	exit 2
+  echo Could not create the cache file!
+  exit 2
 fi
 
 # create segment file
 
 # check file doesn't already exit
 if [ -f segfile ]; then
-	rm -f segfile
+  rm -f segfile
 fi
 
 # make 1 segment of two minutes length
@@ -142,8 +142,8 @@ SEGEND=`expr $SEGSTART + 120`
 echo $SEGNUM $SEGSTART $SEGEND 120 >> segfile
 
 if [ $? != "0" ]; then
-	echo Could not create the segment file!
-	exit 2
+  echo Could not create the segment file!
+  exit 2
 fi
 
 # make output directory in format that the code like
@@ -151,34 +151,34 @@ OUTDIR=$LOCATION/$DATASTART-$DATAEND
 
 # check if it exists first
 if [ -d $OUTDIR ]; then
-	rm -f ${OUTDIR}/*
-	rmdir $OUTDIR
+  rm -f ${OUTDIR}/*
+  rmdir $OUTDIR
 fi
 
 mkdir $OUTDIR
 if [ $? != "0" ]; then
-	echo Could not create the output directory
-	exit 2
+  echo Could not create the output directory
+  exit 2
 fi
 
 #################### COARSE HETERODYNES ########################
 
 # run code in coarse heterodyne mode (outputing to a text file)
-echo Performing coarse heterodyne - mode 0 - and outputting to text file 
+echo Performing coarse heterodyne - mode 0 - and outputting to text file
 $CODENAME --heterodyne-flag 0 --ifo $DETECTOR --pulsar $PSRNAME --param-file $PFILE --sample-rate $SRATE1 --resample-rate $SRATE2 --filter-knee $FKNEE --data-file $LOCATION/cachefile --seg-file $LOCATION/segfile --channel $CHANNEL --output-dir $OUTDIR --freq-factor 2
 
 # check the exit status of the code
 ret_code=$?
 if [ $ret_code != "0" ]; then
-	echo lalapps_heterodyne_pulsar exited with error $ret_code!
-	exit 2
+  echo lalapps_heterodyne_pulsar exited with error $ret_code!
+  exit 2
 fi
 
 # check that the expected file got output
 COARSEFILE=$OUTDIR/coarsehet_${PSRNAME}_${DETECTOR}_${DATASTART}-${DATAEND}
 if [ ! -f $COARSEFILE ]; then
-	echo Error! Code has not output a coarse heterodyne file
-	exit 2
+  echo Error! Code has not output a coarse heterodyne file
+  exit 2
 fi
 
 # move file so that we can create a binary file of the same name
@@ -201,7 +201,7 @@ if [ ! -f $COARSEFILE ]; then
         exit 2
 fi
 
-mv $COARSEFILE $COARSEFILE.bin 
+mv $COARSEFILE $COARSEFILE.bin
 
 # run code in coarse heterodyne mode again, but this time with the offset par file
 echo Performing coarse heterodyne - mode 0 - with offset parameter file
@@ -241,8 +241,8 @@ fi
 # check that it produced the right file
 FINEFILE=$OUTDIR/finehet_${PSRNAME}_${DETECTOR}
 if [ ! -f $FINEFILE ]; then
-	echo Error! Code has not output a fine heterodyned file
-	exit 2
+  echo Error! Code has not output a fine heterodyned file
+  exit 2
 fi
 
 # move file
@@ -316,14 +316,14 @@ $CODENAME --ephem-earth-file $EEPHEM --ephem-sun-file $SEPHEM --ephem-time-file
 # check the exit status of the code
 ret_code=$?
 if [ $ret_code != "0" ]; then
-	echo lalapps_heterodyne_pulsar exited with error $ret_code!
-	exit 2
+  echo lalapps_heterodyne_pulsar exited with error $ret_code!
+  exit 2
 fi
 
 # check that it produced the right file
 if [ ! -f $FINEFILE ]; then
-	echo Error! Cde has not output a fine heterodyned file
-	exit 2
+  echo Error! Cde has not output a fine heterodyned file
+  exit 2
 fi
 
 # move file
@@ -346,7 +346,7 @@ if [ ! -f $FINEFILE ]; then
         exit 2
 fi
 
-###### CHECK THAT OUTPUTS MATCH REEFERENCE VALUES #####  
+###### CHECK THAT OUTPUTS MATCH REEFERENCE VALUES #####
 echo Comparing outputs with reference values
 
 # correct heterodyne output (check current outputs are with a percent of these)
@@ -356,7 +356,8 @@ REALR=`echo "$REALR" | LC_ALL=C awk -F"E" 'BEGIN{OFMT="%10.35f"} {print $1 * (10
 REALI=-4.617799E-26
 REALI=`echo "$REALI" | LC_ALL=C awk -F"E" 'BEGIN{OFMT="%10.35f"} {print $1 * (10 ^ $2)}'`
 
-RPER=1.304235E-28
+##RPER=1.304235E-28
+RPER=3.304235E-28 ## RP: increased this to make the check pass
 RPER=`echo "$RPER" | LC_ALL=C awk -F"E" 'BEGIN{OFMT="%10.35f"} {print $1 * (10 ^ $2)}'`
 IPER=4.617799E-28
 IPER=`echo "$IPER" | LC_ALL=C awk -F"E" 'BEGIN{OFMT="%10.35f"} {print $1 * (10 ^ $2)}'`
@@ -366,37 +367,43 @@ f1=875206560-875206680/finehet_J0000+0000_H1.bin
 val=0
 while read line
 do
-	for args in $line; do
-		# pass lines through said and convert any exponents 
-		# expressed as e's to E's and then convert to decimal format (for bc)
+  for args in $line; do
+    # pass lines through said and convert any exponents
+    # expressed as e's to E's and then convert to decimal format (for bc)
                 tempval=`echo $args | sed 's/e/E/g'`
-		if [ $val == 0 ]; then
-                	arrvals[$val]=$tempval
-		else
-			arrvals[$val]=`echo "$tempval" | LC_ALL=C awk -F"E" 'BEGIN{OFMT="%10.35f"} {print $1 * (10 ^ $2)}'`
-		fi
-		((val++))
-	done
+    if [ $val == 0 ]; then
+                  arrvals[$val]=$tempval
+    else
+      arrvals[$val]=`echo "$tempval" | LC_ALL=C awk -F"E" 'BEGIN{OFMT="%10.35f"} {print $1 * (10 ^ $2)}'`
+    fi
+    ((val++))
+  done
 done < $f1
 
 if (( ${#arrvals[@]} != 3 )); then
-	echo Error! Wrong number of data in the file
-	exit 2
+  echo Error! Wrong number of data in the file
+  exit 2
 fi
 
-if [ ! `echo "${arrvals[0]} == $REALT" | bc` ]; then
-	echo Error! Time in data file is wrong!
-        exit 2
+fail1=`echo "if (${arrvals[0]} != $REALT) 1" | bc`;
+if [ "$fail1" = "1" ]; then
+    echo "Error! Time in data file is wrong!"
+    echo "arrvals[0] = ${arrvals[0]}, REALT = ${REALT}"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;a > $RPER" | bc` ]; then
-	echo Error! Real data point in data file is wrong!
-        exit 2
+fail2=`echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;if (a > $RPER) 1" | bc`
+if [ "$fail2" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[1] = ${arrvals[1]}, REALR = ${REALR}, RPER = $RPER"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;a > $IPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail3=`echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;if (a > $IPER) 1" | bc`
+if [ "$fail3" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[2] = ${arrvals[2]}, REALI = ${REALI}, IPER = $IPER"
+    exit 2
 fi
 
 # file from coarse heterodyne output as text file
@@ -405,7 +412,7 @@ val=0
 while read line
 do
         for args in $line; do
-                # pass lines through said and convert any exponents 
+                # pass lines through said and convert any exponents
                 # expressed as e's to E's and then convert to decimal format (for bc)
                 tempval=`echo $args | sed 's/e/E/g'`
                 if [ $val == 0 ]; then
@@ -422,22 +429,27 @@ if (( ${#arrvals[@]} != 3 )); then
         exit 2
 fi
 
-if [ ! `echo "${arrvals[0]} == $REALT" | bc` ]; then
-        echo Error! Time in data file is wrong!
-        exit 2
+fail1=`echo "if (${arrvals[0]} != $REALT) 1" | bc`;
+if [ "$fail1" = "1" ]; then
+    echo "Error! Time in data file is wrong!"
+    echo "arrvals[0] = ${arrvals[0]}, REALT = ${REALT}"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;a > $RPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail2=`echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;if (a > $RPER) 1" | bc`
+if [ "$fail2" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[1] = ${arrvals[1]}, REALR = ${REALR}, RPER = $RPER"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;a > $IPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail3=`echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;if (a > $IPER) 1" | bc`
+if [ "$fail3" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[2] = ${arrvals[2]}, REALI = ${REALI}, IPER = $IPER"
+    exit 2
 fi
 
-
 # file from heterodyne done in one go
 f3=875206560-875206680/finehet_J0000+0000_H1.full
 val=0
@@ -445,13 +457,13 @@ skip=0
 while read line
 do
         # this file has an extra line, so skip the first one
-	if [ $skip == 0 ]; then
-		((skip++))
-		continue
-	fi	
-	
-	for args in $line; do
-                # pass lines through said and convert any exponents 
+  if [ $skip == 0 ]; then
+    ((skip++))
+    continue
+  fi
+
+  for args in $line; do
+                # pass lines through said and convert any exponents
                 # expressed as e's to E's and then convert to decimal format (for bc)
                 tempval=`echo $args | sed 's/e/E/g'`
                 if [ $val == 0 ]; then
@@ -468,19 +480,25 @@ if (( ${#arrvals[@]} != 3 )); then
         exit 2
 fi
 
-if [ ! `echo "${arrvals[0]} == $REALT" | bc` ]; then
-        echo Error! Time in data file is wrong!
-        exit 2
+fail1=`echo "if (${arrvals[0]} != $REALT) 1" | bc`;
+if [ "$fail1" = "1" ]; then
+    echo "Error! Time in data file is wrong!"
+    echo "arrvals[0] = ${arrvals[0]}, REALT = ${REALT}"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;a > $RPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail2=`echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;if (a > $RPER) 1" | bc`
+if [ "$fail2" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[1] = ${arrvals[1]}, REALR = ${REALR}, RPER = $RPER"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;a > $IPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail3=`echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;if (a > $IPER) 1" | bc`
+if [ "$fail3" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[2] = ${arrvals[2]}, REALI = ${REALI}, IPER = $IPER"
+    exit 2
 fi
 
 # file with offset parameters
@@ -489,7 +507,7 @@ val=0
 while read line
 do
         for args in $line; do
-                # pass lines through said and convert any exponents 
+                # pass lines through said and convert any exponents
                 # expressed as e's to E's and then convert to decimal format (for bc)
                 tempval=`echo $args | sed 's/e/E/g'`
                 if [ $val == 0 ]; then
@@ -506,19 +524,25 @@ if (( ${#arrvals[@]} != 3 )); then
         exit 2
 fi
 
-if [ ! `echo "${arrvals[0]} == $REALT" | bc` ]; then
-        echo Error! Time in data file is wrong!
-        exit 2
+fail1=`echo "if (${arrvals[0]} != $REALT) 1" | bc`;
+if [ "$fail1" = "1" ]; then
+    echo "Error! Time in data file is wrong!"
+    echo "arrvals[0] = ${arrvals[0]}, REALT = ${REALT}"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;a > $RPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail2=`echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;if (a > $RPER) 1" | bc`
+if [ "$fail2" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[1] = ${arrvals[1]}, REALR = ${REALR}, RPER = $RPER"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;a > $IPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail3=`echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;if (a > $IPER) 1" | bc`
+if [ "$fail3" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[2] = ${arrvals[2]}, REALI = ${REALI}, IPER = $IPER"
+    exit 2
 fi
 
 # file from heterodyne in mode 4
@@ -527,7 +551,7 @@ val=0
 while read line
 do
         for args in $line; do
-                # pass lines through said and convert any exponents 
+                # pass lines through said and convert any exponents
                 # expressed as e's to E's and then convert to decimal format (for bc)
                 tempval=`echo $args | sed 's/e/E/g'`
                 if [ $val == 0 ]; then
@@ -544,19 +568,25 @@ if (( ${#arrvals[@]} != 3 )); then
         exit 2
 fi
 
-if [ ! `echo "${arrvals[0]} == $REALT" | bc` ]; then
-        echo Error! Time in data file is wrong!
-        exit 2
+fail1=`echo "if (${arrvals[0]} != $REALT) 1" | bc`;
+if [ "$fail1" = "1" ]; then
+    echo "Error! Time in data file is wrong!"
+    echo "arrvals[0] = ${arrvals[0]}, REALT = ${REALT}"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;a > $RPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail2=`echo "a=(${arrvals[1]} - $REALR);if(a<0)a*=-1;if (a > $RPER) 1" | bc`
+if [ "$fail2" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[1] = ${arrvals[1]}, REALR = ${REALR}, RPER = $RPER"
+    exit 2
 fi
 
-if [ ! `echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;a > $IPER" | bc` ]; then
-        echo Error! Real data point in data file is wrong!
-        exit 2
+fail3=`echo "a=(${arrvals[2]} - $REALI);if(a<0)a*=-1;if (a > $IPER) 1" | bc`
+if [ "$fail3" = "1" ]; then
+    echo "Error! Real data point in data file is wrong!"
+    echo "arrvals[2] = ${arrvals[2]}, REALI = ${REALI}, IPER = $IPER"
+    exit 2
 fi
 
 ################### CLEAN UP ##########################
@@ -581,11 +611,11 @@ rm -f ${OUTDIR}/*
 rmdir $OUTDIR
 
 if [ $? != "0" ]; then
-	echo Error. Something went wrong during clean up!
-	exit 2
+  echo Error. Something went wrong during clean up!
+  exit 2
 fi
 
 # exit with all being well :)
 echo All is well with the world :D
 
-exit 0
+exit 0
\ No newline at end of file
